# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'arcjetCV.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PySide6 import QtCore, QtGui, QtWidgets
from PySide6.QtGui import QAction
from arcjetCV.gui.custom_classes import MatplotlibWidget


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(800, 500)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.tab)
        self.formLayout_8 = QtWidgets.QFormLayout()
        self.formLayout_8.setFieldGrowthPolicy(
            QtWidgets.QFormLayout.AllNonFixedFieldsGrow
        )
        self.formLayout_8.setLabelAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.Window0 = MatplotlibWidget(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        self.Window0.setSizePolicy(sizePolicy)
        self.Window0.setMaximumSize(QtCore.QSize(16777215, 16777215))
        # self.Window0.setMouseTracking(True)
        self.Window0.setObjectName("label_img")
        self.Window0.adjustSize()
        self.verticalLayout.addWidget(self.Window0)
        self.Window3 = MatplotlibWidget(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Window3.sizePolicy().hasHeightForWidth())
        self.Window3.setSizePolicy(sizePolicy)
        self.Window3.setMinimumSize(QtCore.QSize(731, 100))
        self.Window3.setMaximumSize(QtCore.QSize(16777215, 70))
        self.Window3.setObjectName("Window3")
        self.verticalLayout.addWidget(self.Window3)
        spacerItem = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        self.verticalLayout.addItem(spacerItem)
        self.horizontalLayout_8.addLayout(self.verticalLayout)
        spacerItem1 = QtWidgets.QSpacerItem(
            40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        self.horizontalLayout_8.addItem(spacerItem1)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.pushButton_loadVideo = QtWidgets.QPushButton(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_loadVideo.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_loadVideo.setSizePolicy(sizePolicy)
        self.pushButton_loadVideo.setObjectName("pushButton_loadVideo")
        self.verticalLayout_6.addWidget(self.pushButton_loadVideo)
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setMinimumSize(QtCore.QSize(350, 0))
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setLabelAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.formLayout.setObjectName("formLayout")
        self.label_7 = QtWidgets.QLabel(self.groupBox_2)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.spinBox_FrameIndex = QtWidgets.QSpinBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.spinBox_FrameIndex.sizePolicy().hasHeightForWidth()
        )
        self.spinBox_FrameIndex.setSizePolicy(sizePolicy)
        self.spinBox_FrameIndex.setMaximum(100000)
        self.spinBox_FrameIndex.setProperty("value", 0)
        self.spinBox_FrameIndex.setObjectName("spinBox_FrameIndex")
        self.formLayout.setWidget(
            0, QtWidgets.QFormLayout.FieldRole, self.spinBox_FrameIndex
        )
        self.label_3 = QtWidgets.QLabel(self.groupBox_2)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.comboBox_flowDirection = QtWidgets.QComboBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.comboBox_flowDirection.sizePolicy().hasHeightForWidth()
        )
        self.comboBox_flowDirection.setSizePolicy(sizePolicy)
        self.comboBox_flowDirection.setObjectName("comboBox_flowDirection")
        self.comboBox_flowDirection.addItem("")
        self.comboBox_flowDirection.addItem("")
        self.comboBox_flowDirection.addItem("")
        self.comboBox_flowDirection.addItem("")
        self.formLayout.setWidget(
            1, QtWidgets.QFormLayout.FieldRole, self.comboBox_flowDirection
        )
        self.comboBox_filterType = QtWidgets.QComboBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.comboBox_filterType.sizePolicy().hasHeightForWidth()
        )
        self.comboBox_filterType.setSizePolicy(sizePolicy)
        self.comboBox_filterType.setObjectName("comboBox_filterType")
        self.comboBox_filterType.addItem("")
        self.comboBox_filterType.addItem("")
        self.comboBox_filterType.addItem("")
        self.comboBox_filterType.addItem("")
        self.formLayout.setWidget(
            2, QtWidgets.QFormLayout.FieldRole, self.comboBox_filterType
        )
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.verticalLayout_5.addLayout(self.formLayout)
        self.FilterTabs = QtWidgets.QTabWidget(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FilterTabs.sizePolicy().hasHeightForWidth())
        self.FilterTabs.setSizePolicy(sizePolicy)
        self.FilterTabs.setObjectName("FilterTabs")

        self.label_display_shock = QtWidgets.QLabel(self.groupBox_2)
        self.label_display_shock.setObjectName("label_display_shock")
        self.formLayout.setWidget(
            3, QtWidgets.QFormLayout.LabelRole, self.label_display_shock
        )
        self.label_display_shock.setText("Display Shock:")

        self.checkBox_display_shock = QtWidgets.QCheckBox(self.groupBox_2)
        self.checkBox_display_shock.setObjectName("checkBox_display_shock")
        self.formLayout.setWidget(
            3, QtWidgets.QFormLayout.FieldRole, self.checkBox_display_shock
        )
        self.checkBox_display_shock.setChecked(True)

        self.tab_7 = QtWidgets.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.formLayout_8 = QtWidgets.QFormLayout(self.tab_7)
        self.formLayout_8.setFieldGrowthPolicy(
            QtWidgets.QFormLayout.AllNonFixedFieldsGrow
        )
        self.formLayout_8.setLabelAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.formLayout_8.setContentsMargins(0, 0, 0, 0)
        self.formLayout_8.setObjectName("formLayout_8")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.spinBox_crop_xmin = QtWidgets.QSpinBox(self.tab_7)
        self.spinBox_crop_xmin.setMaximum(10000)
        self.spinBox_crop_xmin.setProperty("value", 20)
        self.spinBox_crop_xmin.setObjectName("spinBox_crop_xmin")
        self.horizontalLayout_18.addWidget(self.spinBox_crop_xmin)
        self.spinBox_crop_xmax = QtWidgets.QSpinBox(self.tab_7)
        self.spinBox_crop_xmax.setMaximum(10000)
        self.spinBox_crop_xmax.setProperty("value", 20)
        self.spinBox_crop_xmax.setObjectName("spinBox_crop_xmax")
        self.horizontalLayout_18.addWidget(self.spinBox_crop_xmax)
        self.formLayout_8.setLayout(
            0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_18
        )
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.spinBox_crop_ymin = QtWidgets.QSpinBox(self.tab_7)
        self.spinBox_crop_ymin.setMaximum(10000)
        self.spinBox_crop_ymin.setProperty("value", 100)
        self.spinBox_crop_ymin.setObjectName("spinBox_crop_ymin")
        self.horizontalLayout_19.addWidget(self.spinBox_crop_ymin)
        self.spinBox_crop_ymax = QtWidgets.QSpinBox(self.tab_7)
        self.spinBox_crop_ymax.setMaximum(10000)
        self.spinBox_crop_ymax.setProperty("value", 100)
        self.spinBox_crop_ymax.setObjectName("spinBox_crop_ymax")
        self.horizontalLayout_19.addWidget(self.spinBox_crop_ymax)
        self.formLayout_8.setLayout(
            1, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_19
        )
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")

        # Create horizontal layout for checkboxes
        self.horizontalLayout_checkboxes = QtWidgets.QHBoxLayout()
        self.horizontalLayout_checkboxes.setObjectName("horizontalLayout_checkboxes")

        self.checkBox_crop = QtWidgets.QCheckBox(self.tab_7)
        self.checkBox_crop.setChecked(True)
        self.checkBox_crop.setTristate(False)
        self.checkBox_crop.setObjectName("checkBox_crop")
        self.horizontalLayout_checkboxes.addWidget(self.checkBox_crop)

        self.checkBox_annotate = QtWidgets.QCheckBox(self.tab_7)
        self.checkBox_annotate.setChecked(True)
        self.checkBox_annotate.setObjectName("checkBox_annotate")
        self.horizontalLayout_checkboxes.addWidget(self.checkBox_annotate)

        # Add the horizontal layout with checkboxes to the form layout
        self.formLayout_8.setLayout(
            2, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_checkboxes
        )

        # Create the applyCrop push button
        self.applyCrop = QtWidgets.QPushButton(self.tab_7)
        self.applyCrop.setObjectName("pushButton")

        # Place the applyCrop button below the horizontal layout of checkboxes in the form layout
        self.formLayout_8.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.applyCrop)
        self.label_19 = QtWidgets.QLabel(self.tab_7)
        self.label_19.setObjectName("label_19")
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_19)
        self.label_21 = QtWidgets.QLabel(self.tab_7)
        self.label_21.setObjectName("label_21")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_21)

        self.FilterTabs.addTab(self.tab_7, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab_3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setFieldGrowthPolicy(
            QtWidgets.QFormLayout.AllNonFixedFieldsGrow
        )
        self.formLayout_2.setLabelAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_8 = QtWidgets.QLabel(self.tab_3)
        self.label_8.setObjectName("label_8")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.minHue = QtWidgets.QSpinBox(self.tab_3)
        self.minHue.setMaximum(180)
        self.minHue.setProperty("value", 0)
        self.minHue.setObjectName("minHue")
        self.horizontalLayout_3.addWidget(self.minHue)
        self.maxHue = QtWidgets.QSpinBox(self.tab_3)
        self.maxHue.setMaximum(180)
        self.maxHue.setProperty("value", 121)
        self.maxHue.setObjectName("maxHue")
        self.horizontalLayout_3.addWidget(self.maxHue)
        self.formLayout_2.setLayout(
            0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_3
        )
        self.label_9 = QtWidgets.QLabel(self.tab_3)
        self.label_9.setObjectName("label_9")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.minSaturation = QtWidgets.QSpinBox(self.tab_3)
        self.minSaturation.setMaximum(255)
        self.minSaturation.setProperty("value", 0)
        self.minSaturation.setObjectName("minSaturation")
        self.horizontalLayout_4.addWidget(self.minSaturation)
        self.maxSaturation = QtWidgets.QSpinBox(self.tab_3)
        self.maxSaturation.setMaximum(255)
        self.maxSaturation.setProperty("value", 125)
        self.maxSaturation.setObjectName("maxSaturation")
        self.horizontalLayout_4.addWidget(self.maxSaturation)
        self.formLayout_2.setLayout(
            1, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_4
        )
        self.label_5 = QtWidgets.QLabel(self.tab_3)
        self.label_5.setObjectName("label_5")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.minIntensity = QtWidgets.QSpinBox(self.tab_3)
        self.minIntensity.setMaximum(254)
        self.minIntensity.setProperty("value", 150)
        self.minIntensity.setObjectName("minIntensity")
        self.horizontalLayout_2.addWidget(self.minIntensity)
        self.maxIntensity = QtWidgets.QSpinBox(self.tab_3)
        self.maxIntensity.setMaximum(255)
        self.maxIntensity.setProperty("value", 255)
        self.maxIntensity.setObjectName("maxIntensity")
        self.horizontalLayout_2.addWidget(self.maxIntensity)
        self.formLayout_2.setLayout(
            2, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_2
        )
        self.verticalLayout_2.addLayout(self.formLayout_2)
        self.FilterTabs.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.tab_4)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.formLayout_4 = QtWidgets.QFormLayout()
        self.formLayout_4.setFieldGrowthPolicy(
            QtWidgets.QFormLayout.AllNonFixedFieldsGrow
        )
        self.formLayout_4.setLabelAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.formLayout_4.setObjectName("formLayout_4")
        self.label_15 = QtWidgets.QLabel(self.tab_4)
        self.label_15.setObjectName("label_15")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_15)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.minHue_2 = QtWidgets.QSpinBox(self.tab_4)
        self.minHue_2.setMaximum(180)
        self.minHue_2.setProperty("value", 125)
        self.minHue_2.setObjectName("minHue_2")
        self.horizontalLayout_6.addWidget(self.minHue_2)
        self.maxHue_2 = QtWidgets.QSpinBox(self.tab_4)
        self.maxHue_2.setMaximum(180)
        self.maxHue_2.setProperty("value", 170)
        self.maxHue_2.setObjectName("maxHue_2")
        self.horizontalLayout_6.addWidget(self.maxHue_2)
        self.formLayout_4.setLayout(
            1, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_6
        )
        self.label_16 = QtWidgets.QLabel(self.tab_4)
        self.label_16.setObjectName("label_16")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_16)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.minSaturation_2 = QtWidgets.QSpinBox(self.tab_4)
        self.minSaturation_2.setMaximum(255)
        self.minSaturation_2.setProperty("value", 40)
        self.minSaturation_2.setObjectName("minSaturation_2")
        self.horizontalLayout_7.addWidget(self.minSaturation_2)
        self.maxSaturation_2 = QtWidgets.QSpinBox(self.tab_4)
        self.maxSaturation_2.setMaximum(255)
        self.maxSaturation_2.setProperty("value", 80)
        self.maxSaturation_2.setObjectName("maxSaturation_2")
        self.horizontalLayout_7.addWidget(self.maxSaturation_2)
        self.formLayout_4.setLayout(
            2, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_7
        )
        self.label_6 = QtWidgets.QLabel(self.tab_4)
        self.label_6.setObjectName("label_6")
        self.formLayout_4.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.minIntensity_2 = QtWidgets.QSpinBox(self.tab_4)
        self.minIntensity_2.setMaximum(254)
        self.minIntensity_2.setProperty("value", 85)
        self.minIntensity_2.setObjectName("minIntensity_2")
        self.horizontalLayout_5.addWidget(self.minIntensity_2)
        self.maxIntensity_2 = QtWidgets.QSpinBox(self.tab_4)
        self.maxIntensity_2.setMaximum(255)
        self.maxIntensity_2.setProperty("value", 230)
        self.maxIntensity_2.setObjectName("maxIntensity_2")
        self.horizontalLayout_5.addWidget(self.maxIntensity_2)
        self.formLayout_4.setLayout(
            3, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_5
        )
        self.horizontalLayout_9.addLayout(self.formLayout_4)
        self.FilterTabs.addTab(self.tab_4, "")
        self.verticalLayout_5.addWidget(self.FilterTabs)
        self.verticalLayout_6.addWidget(self.groupBox_2)
        self.groupBox = QtWidgets.QGroupBox(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.formLayout_5 = QtWidgets.QFormLayout()
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_17 = QtWidgets.QLabel(self.groupBox)
        self.label_17.setObjectName("label_17")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_17)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.spinBox_FirstGoodFrame = QtWidgets.QSpinBox(self.groupBox)
        self.spinBox_FirstGoodFrame.setMaximum(100000)
        self.spinBox_FirstGoodFrame.setProperty("value", 0)
        self.spinBox_FirstGoodFrame.setObjectName("spinBox_FirstGoodFrame")
        self.horizontalLayout_10.addWidget(self.spinBox_FirstGoodFrame)
        self.spinBox_LastGoodFrame = QtWidgets.QSpinBox(self.groupBox)
        self.spinBox_LastGoodFrame.setMaximum(100000)
        self.spinBox_LastGoodFrame.setProperty("value", 0)
        self.spinBox_LastGoodFrame.setObjectName("spinBox_LastGoodFrame")
        self.horizontalLayout_10.addWidget(self.spinBox_LastGoodFrame)
        self.formLayout_5.setLayout(
            0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_10
        )
        self.label_20 = QtWidgets.QLabel(self.groupBox)
        self.label_20.setObjectName("label_20")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_20)
        self.lineEdit_filename = QtWidgets.QLineEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.lineEdit_filename.sizePolicy().hasHeightForWidth()
        )
        self.lineEdit_filename.setSizePolicy(sizePolicy)
        self.lineEdit_filename.setObjectName("lineEdit_filename")
        self.formLayout_5.setWidget(
            2, QtWidgets.QFormLayout.FieldRole, self.lineEdit_filename
        )
        self.spinBox_frame_skips = QtWidgets.QSpinBox(self.groupBox)
        self.spinBox_frame_skips.setMinimum(1)
        self.spinBox_frame_skips.setMaximum(500)
        self.spinBox_frame_skips.setProperty("value", 5)
        self.spinBox_frame_skips.setObjectName("spinBox_frame_skips")
        self.formLayout_5.setWidget(
            1, QtWidgets.QFormLayout.FieldRole, self.spinBox_frame_skips
        )
        self.label_10 = QtWidgets.QLabel(self.groupBox)
        self.label_10.setObjectName("label_10")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.verticalLayout_3.addLayout(self.formLayout_5)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.checkBox_writeVideo = QtWidgets.QCheckBox(self.groupBox)
        self.checkBox_writeVideo.setObjectName("checkBox_writeVideo")
        self.horizontalLayout.addWidget(self.checkBox_writeVideo)
        self.pushButton_process = QtWidgets.QPushButton(self.groupBox)
        self.pushButton_process.setObjectName("pushButton_process")
        self.horizontalLayout.addWidget(self.pushButton_process)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.verticalLayout_6.addWidget(self.groupBox)
        spacerItemH = QtWidgets.QSpacerItem(
            40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        self.verticalLayout_6.addItem(spacerItemH)
        spacerItem2 = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout_6.addItem(spacerItem2)
        self.horizontalLayout_8.addLayout(self.verticalLayout_6)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.Window1 = MatplotlibWidget(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Window1.sizePolicy().hasHeightForWidth())
        self.Window1.setSizePolicy(sizePolicy)
        self.Window1.setMinimumSize(QtCore.QSize(550, 400))
        self.Window1.setObjectName("Window1")
        self.horizontalLayout_12.addWidget(self.Window1)
        self.Window2 = MatplotlibWidget(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Window2.sizePolicy().hasHeightForWidth())
        self.Window2.setSizePolicy(sizePolicy)
        self.Window2.setMinimumSize(QtCore.QSize(400, 350))
        self.Window2.setObjectName("Window2")
        self.horizontalLayout_12.addWidget(self.Window2)
        self.verticalLayout_8.addLayout(self.horizontalLayout_12)
        self.textBrowser = QtWidgets.QTextBrowser(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textBrowser.sizePolicy().hasHeightForWidth())
        self.textBrowser.setSizePolicy(sizePolicy)
        self.textBrowser.setMaximumSize(QtCore.QSize(16777215, 250))
        self.textBrowser.setObjectName("textBrowser")
        self.verticalLayout_8.addWidget(self.textBrowser)
        self.horizontalLayout_11.addLayout(self.verticalLayout_8)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.pushButton_LoadFiles = QtWidgets.QPushButton(self.tab_2)
        self.pushButton_LoadFiles.setObjectName("pushButton_LoadFiles")
        self.horizontalLayout_13.addWidget(self.pushButton_LoadFiles)
        self.pushButton_export_csv = QtWidgets.QPushButton(self.tab_2)
        self.pushButton_export_csv.setObjectName("pushButton_export_csv")
        self.horizontalLayout_13.addWidget(self.pushButton_export_csv)
        self.verticalLayout_7.addLayout(self.horizontalLayout_13)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.pushButton_PlotData = QtWidgets.QPushButton(self.tab_2)
        self.pushButton_PlotData.setObjectName("pushButton_PlotData")
        self.horizontalLayout_15.addWidget(self.pushButton_PlotData)
        self.pushButton_fitData = QtWidgets.QPushButton(self.tab_2)
        self.pushButton_fitData.setObjectName("pushButton_fitData")
        self.horizontalLayout_15.addWidget(self.pushButton_fitData)
        self.verticalLayout_7.addLayout(self.horizontalLayout_15)
        self.tabWidget_2 = QtWidgets.QTabWidget(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget_2.sizePolicy().hasHeightForWidth())
        self.tabWidget_2.setSizePolicy(sizePolicy)
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.formLayout_3 = QtWidgets.QFormLayout(self.tab_5)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_11 = QtWidgets.QLabel(self.tab_5)
        self.label_11.setObjectName("label_11")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.label_18 = QtWidgets.QLabel(self.tab_5)
        self.label_18.setObjectName("label_18")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_18)
        self.doubleSpinBox_diameter = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.doubleSpinBox_diameter.setMinimum(0.1)
        self.doubleSpinBox_diameter.setMaximum(1000.0)
        self.doubleSpinBox_diameter.setProperty("value", 101.6)
        self.doubleSpinBox_diameter.setObjectName("doubleSpinBox_diameter")
        self.formLayout_3.setWidget(
            0, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBox_diameter
        )
        self.comboBox_units = QtWidgets.QComboBox(self.tab_5)
        self.comboBox_units.setObjectName("comboBox_units")
        self.comboBox_units.addItem("")
        self.comboBox_units.addItem("")
        self.comboBox_units.addItem("")
        self.comboBox_units.addItem("")
        self.formLayout_3.setWidget(
            2, QtWidgets.QFormLayout.FieldRole, self.comboBox_units
        )
        self.doubleSpinBox_fps = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.doubleSpinBox_fps.setMinimum(0.0)
        self.doubleSpinBox_fps.setMaximum(1200000.0)
        self.doubleSpinBox_fps.setProperty("value", 30.0)
        self.doubleSpinBox_fps.setObjectName("doubleSpinBox_fps")
        self.formLayout_3.setWidget(
            4, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBox_fps
        )
        self.spinBox_mask_frames = QtWidgets.QSpinBox(self.tab_5)
        self.spinBox_mask_frames.setMinimumSize(QtCore.QSize(0, 0))
        self.spinBox_mask_frames.setMinimum(1)
        self.spinBox_mask_frames.setMaximum(1000)
        self.spinBox_mask_frames.setProperty("value", 1)
        self.spinBox_mask_frames.setObjectName("spinBox_mask_frames")
        self.formLayout_3.setWidget(
            6, QtWidgets.QFormLayout.FieldRole, self.spinBox_mask_frames
        )
        self.label_2 = QtWidgets.QLabel(self.tab_5)
        self.label_2.setObjectName("label_2")
        self.formLayout_3.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.label_display_shock2 = QtWidgets.QLabel(self.tab_5)
        self.label_display_shock2.setObjectName("label_display_shock")
        self.label_display_shock2.setText("Display Shock")
        self.formLayout_3.setWidget(
            7, QtWidgets.QFormLayout.LabelRole, self.label_display_shock2
        )

        self.checkBox_display_shock2 = QtWidgets.QCheckBox(self.tab_5)
        self.checkBox_display_shock2.setObjectName("checkBox_display_shock")
        self.formLayout_3.setWidget(
            7, QtWidgets.QFormLayout.FieldRole, self.checkBox_display_shock2
        )
        self.checkBox_display_shock2.setChecked(True)
        self.tabWidget_2.addTab(self.tab_5, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.tab_6)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_6)
        self.groupBox_3.setObjectName("groupBox_3")
        self.formLayout_6 = QtWidgets.QFormLayout(self.groupBox_3)
        self.formLayout_6.setObjectName("formLayout_6")
        self.comboBox_fit_type = QtWidgets.QComboBox(self.groupBox_3)
        self.comboBox_fit_type.setObjectName("comboBox_fit_type")
        self.comboBox_fit_type.addItem("")
        self.formLayout_6.setWidget(
            0, QtWidgets.QFormLayout.FieldRole, self.comboBox_fit_type
        )
        self.label_12 = QtWidgets.QLabel(self.groupBox_3)
        self.label_12.setObjectName("label_12")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.label_13 = QtWidgets.QLabel(self.groupBox_3)
        self.label_13.setObjectName("label_13")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_13)
        self.label_14 = QtWidgets.QLabel(self.groupBox_3)
        self.label_14.setObjectName("label_14")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_14)
        self.doubleSpinBox_fit_start_time = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.doubleSpinBox_fit_start_time.setObjectName("doubleSpinBox_fit_start_time")
        self.formLayout_6.setWidget(
            1, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBox_fit_start_time
        )
        self.doubleSpinBox_fit_last_time = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.doubleSpinBox_fit_last_time.setObjectName("doubleSpinBox_fit_last_time")
        self.formLayout_6.setWidget(
            2, QtWidgets.QFormLayout.FieldRole, self.doubleSpinBox_fit_last_time
        )
        self.verticalLayout_10.addWidget(self.groupBox_3)
        self.tabWidget_2.addTab(self.tab_6, "")
        self.verticalLayout_7.addWidget(self.tabWidget_2)
        self.groupBox_XT_params = QtWidgets.QGroupBox(self.tab_2)
        self.groupBox_XT_params.setObjectName("groupBox_XT_params")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_XT_params)
        self.gridLayout.setObjectName("gridLayout")
        self.checkBox_95_radius = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_95_radius.setChecked(False)
        self.checkBox_95_radius.setObjectName("checkBox_95_radius")
        self.gridLayout.addWidget(self.checkBox_95_radius, 4, 0, 1, 1)
        self.checkBox_m50_radius = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_m50_radius.setChecked(True)
        self.checkBox_m50_radius.setObjectName("checkBox_m50_radius")
        self.gridLayout.addWidget(self.checkBox_m50_radius, 1, 0, 1, 1)
        self.checkBox_ypos = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_ypos.setObjectName("checkBox_ypos")
        self.gridLayout.addWidget(self.checkBox_ypos, 4, 1, 1, 1)
        self.checkBox_50_radius = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_50_radius.setChecked(True)
        self.checkBox_50_radius.setObjectName("checkBox_50_radius")
        self.gridLayout.addWidget(self.checkBox_50_radius, 3, 0, 1, 1)
        self.checkBox_shockmodel = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_shockmodel.setObjectName("checkBox_shockmodel")
        self.gridLayout.addWidget(self.checkBox_shockmodel, 3, 1, 1, 1)
        self.checkBox_shock_center = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_shock_center.setObjectName("checkBox_shock_center")
        self.gridLayout.addWidget(self.checkBox_shock_center, 2, 1, 1, 1)
        self.checkBox_model_center = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_model_center.setChecked(True)
        self.checkBox_model_center.setObjectName("checkBox_model_center")
        self.gridLayout.addWidget(self.checkBox_model_center, 2, 0, 1, 1)
        self.checkBox_m95_radius = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_m95_radius.setChecked(False)
        self.checkBox_m95_radius.setTristate(False)
        self.checkBox_m95_radius.setObjectName("checkBox_m95_radius")
        self.gridLayout.addWidget(self.checkBox_m95_radius, 0, 0, 1, 1)
        self.checkBox_model_rad = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_model_rad.setObjectName("checkBox_model_rad")
        self.gridLayout.addWidget(self.checkBox_model_rad, 1, 1, 1, 1)
        self.checkBox_shock_area = QtWidgets.QCheckBox(self.groupBox_XT_params)
        self.checkBox_shock_area.setObjectName("checkBox_shock_area")
        self.gridLayout.addWidget(self.checkBox_shock_area, 0, 1, 1, 1)
        self.verticalLayout_7.addWidget(self.groupBox_XT_params)
        self.groupBox_data_summary = QtWidgets.QGroupBox(self.tab_2)
        self.groupBox_data_summary.setObjectName("groupBox_data_summary")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.groupBox_data_summary)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.label_data_summary = QtWidgets.QLabel(self.groupBox_data_summary)
        self.label_data_summary.setText("")
        self.label_data_summary.setObjectName("label_data_summary")
        self.verticalLayout_9.addWidget(self.label_data_summary)
        self.verticalLayout_7.addWidget(self.groupBox_data_summary)
        spacerItem3 = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout_7.addItem(spacerItem3)
        self.horizontalLayout_11.addLayout(self.verticalLayout_7)
        self.tabWidget.addTab(self.tab_2, "")
        self.verticalLayout_4.addWidget(self.tabWidget)
        self.basebar = QtWidgets.QLabel(self.centralwidget)
        self.basebar.setText("")
        self.basebar.setObjectName("basebar")
        self.verticalLayout_4.addWidget(self.basebar)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1146, 22))
        self.menubar.setObjectName("menubar")
        self.menuMenu = QtWidgets.QMenu(self.menubar)
        self.menuMenu.setObjectName("menuMenu")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtWidgets.QToolBar(MainWindow)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.actionLoad_video = QAction(MainWindow)
        self.actionLoad_video.setObjectName("actionLoad_video")
        self.actionExit = QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionSave_Filter = QAction(MainWindow)
        self.actionSave_Filter.setObjectName("actionSave_Filter")
        self.actionLoad_Filter_2 = QAction(MainWindow)
        self.actionLoad_Filter_2.setObjectName("actionLoad_Filter_2")
        self.actionSave_Filter_2 = QAction(MainWindow)
        self.actionSave_Filter_2.setObjectName("actionSave_Filter_2")
        self.actionExit_2 = QAction(MainWindow)
        self.actionExit_2.setObjectName("actionExit_2")
        self.menuMenu.addAction(self.actionLoad_video)
        self.menuMenu.addAction(self.actionExit_2)
        self.menubar.addAction(self.menuMenu.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.FilterTabs.setCurrentIndex(0)
        self.tabWidget_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "arcjetCV"))
        self.pushButton_loadVideo.setText(_translate("MainWindow", "Load Video"))
        self.pushButton_loadCalibration.setText(_translate("MainWindow", "Load Calibration"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Input parameters"))
        self.label_7.setText(_translate("MainWindow", "Frame Index:"))
        self.label_3.setText(_translate("MainWindow", "Flow direction:"))
        self.comboBox_flowDirection.setItemText(0, _translate("MainWindow", "right"))
        self.comboBox_flowDirection.setItemText(1, _translate("MainWindow", "left"))
        self.comboBox_flowDirection.setItemText(2, _translate("MainWindow", "up"))
        self.comboBox_flowDirection.setItemText(3, _translate("MainWindow", "down"))
        self.comboBox_filterType.setItemText(0, _translate("MainWindow", "CNN"))
        self.comboBox_filterType.setItemText(1, _translate("MainWindow", "AutoHSV"))
        self.comboBox_filterType.setItemText(2, _translate("MainWindow", "HSV"))
        self.comboBox_filterType.setItemText(3, _translate("MainWindow", "GRAY"))
        self.label_4.setText(_translate("MainWindow", "Filter Method:"))
        self.label_21.setText(_translate("MainWindow", "Y (min:max)"))
        self.label_19.setText(_translate("MainWindow", "X (min:max)"))
        self.checkBox_annotate.setText(_translate("MainWindow", "Annotate?"))
        self.checkBox_crop.setText(_translate("MainWindow", "Show crop?"))
        self.applyCrop.setText(_translate("MainWindow", "Apply"))
        self.FilterTabs.setTabText(
            self.FilterTabs.indexOf(self.tab_7), _translate("MainWindow", "Crop")
        )
        self.label_8.setText(_translate("MainWindow", "Hue (0-180)"))
        self.label_9.setText(_translate("MainWindow", "Saturation (0-255)"))
        self.label_5.setText(_translate("MainWindow", "Value (0-255)"))
        self.FilterTabs.setTabText(
            self.FilterTabs.indexOf(self.tab_3),
            _translate("MainWindow", "Model Filter"),
        )
        self.label_15.setText(_translate("MainWindow", "Hue (0-180)"))
        self.label_16.setText(_translate("MainWindow", "Saturation (0-255)"))
        self.label_6.setText(_translate("MainWindow", "Value (0-255)"))
        self.FilterTabs.setTabText(
            self.FilterTabs.indexOf(self.tab_4),
            _translate("MainWindow", "Shock Filter"),
        )
        self.groupBox.setTitle(_translate("MainWindow", "Output parameters"))
        self.label_17.setText(_translate("MainWindow", "Frame range:"))
        self.label_20.setText(_translate("MainWindow", "Output filename:"))
        self.label_10.setText(_translate("MainWindow", "Process every Nth:"))
        self.checkBox_writeVideo.setText(_translate("MainWindow", "Write video"))
        self.pushButton_process.setText(_translate("MainWindow", "Process All"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Extract Edges")
        )
        self.pushButton_LoadFiles.setText(_translate("MainWindow", "Load Files"))
        self.pushButton_export_csv.setText(_translate("MainWindow", "Export CSV/plots"))
        self.pushButton_PlotData.setText(_translate("MainWindow", "Plot Data"))
        self.pushButton_fitData.setText(_translate("MainWindow", "Fit Data"))
        self.label_11.setText(_translate("MainWindow", "Units:"))
        self.label_18.setText(_translate("MainWindow", "Frames per sec:"))
        self.comboBox_units.setItemText(0, _translate("MainWindow", "[in]"))
        self.comboBox_units.setItemText(1, _translate("MainWindow", "[cm]"))
        self.comboBox_units.setItemText(2, _translate("MainWindow", "[mm]"))
        self.comboBox_units.setItemText(3, _translate("MainWindow", "pixels"))
        self.label_2.setText(_translate("MainWindow", "Mask nframes:"))
        self.tabWidget_2.setTabText(
            self.tabWidget_2.indexOf(self.tab_5),
            _translate("MainWindow", "Plotting parameters"),
        )
        self.groupBox_3.setTitle(_translate("MainWindow", "Fitting Parameters"))
        self.comboBox_fit_type.setItemText(0, _translate("MainWindow", "linear"))
        self.label_12.setText(_translate("MainWindow", "Fit type:"))
        self.label_13.setText(_translate("MainWindow", "Start time:"))
        self.label_14.setText(_translate("MainWindow", "End time:"))
        self.tabWidget_2.setTabText(
            self.tabWidget_2.indexOf(self.tab_6),
            _translate("MainWindow", "Fitting parameters"),
        )
        self.groupBox_XT_params.setTitle(
            _translate("MainWindow", "Visible Traces on XT plot")
        )
        self.checkBox_95_radius.setText(_translate("MainWindow", "+95% radius"))
        self.checkBox_m50_radius.setText(_translate("MainWindow", "-50% radius"))
        self.checkBox_ypos.setText(_translate("MainWindow", "Model axis-position"))
        self.checkBox_50_radius.setText(_translate("MainWindow", "+50% radius "))
        self.checkBox_shockmodel.setText(_translate("MainWindow", "Shock-model dist"))
        self.checkBox_shock_center.setText(_translate("MainWindow", "Shock center"))
        self.checkBox_model_center.setText(_translate("MainWindow", "Model center"))
        self.checkBox_m95_radius.setText(_translate("MainWindow", "-95% radius"))
        self.checkBox_model_rad.setText(_translate("MainWindow", "Model radius"))
        self.checkBox_shock_area.setText(_translate("MainWindow", "Shock area"))
        self.groupBox_data_summary.setTitle(_translate("MainWindow", "Data Summary"))
        self.tabWidget.setTabText(
            self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Analyze")
        )
        self.menuMenu.setTitle(_translate("MainWindow", "Menu"))
        self.toolBar.setWindowTitle(_translate("MainWindow", "toolBar"))
        self.actionLoad_video.setText(_translate("MainWindow", "Load video"))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
        self.actionSave_Filter.setText(_translate("MainWindow", "Save Filter"))
        self.actionLoad_Filter_2.setText(_translate("MainWindow", "Load Filter"))
        self.actionSave_Filter_2.setText(_translate("MainWindow", "Save Filter"))
        self.actionExit_2.setText(_translate("MainWindow", "Exit"))



import pytest
from PySide6.QtWidgets import QApplication, QMessageBox
from PySide6.QtCore import Qt
from arcjetCV.calibration.calibration_view import CalibrationView


@pytest.fixture(scope="module")
def app():
    app = QApplication.instance()
    if app is None:
        app = QApplication([])
    yield app
    app.quit()


@pytest.fixture
def view(app):
    return CalibrationView()


def test_calibration_view_initialization(view):
    """Test that the CalibrationView initializes correctly."""
    assert view is not None
    assert view.print_button.text() == "Print Chessboard"
    assert view.grid_rows_input.value() == 9
    assert view.grid_cols_input.value() == 4
    assert view.ppcm_label.text() == "Calibration Scale: N/A"


def test_grid_size_spinboxes(view):
    """Test the grid size spinboxes for pattern resolution."""
    view.grid_rows_input.setValue(12)
    view.grid_cols_input.setValue(8)

    assert view.grid_rows_input.value() == 12
    assert view.grid_cols_input.value() == 8


def test_button_clicks(view, qtbot):
    """Test main buttons are clickable and exist."""
    # Print button
    qtbot.mouseClick(view.print_button, Qt.LeftButton)
    assert view.print_button.isEnabled()

    # Load calibration image (pattern resolution tab)
    qtbot.mouseClick(view.load_image_button_pattern, Qt.LeftButton)
    assert view.load_image_button_pattern.isEnabled()

    # Load image for ruler resolution tab
    qtbot.mouseClick(view.load_image_button, Qt.LeftButton)
    assert view.load_image_button.isEnabled()

    # Save calibration button
    qtbot.mouseClick(view.save_calibration_button, Qt.LeftButton)
    assert view.save_calibration_button.isEnabled()


def test_diagonal_input(view):
    """Test the diagonal distance input widget."""
    view.diagonal_distance_value.setValue(150.0)
    assert view.diagonal_distance_value.value() == 150.0


def test_real_world_length_input(view):
    """Test the ruler-based real-world length input."""
    test_value = "123.45"
    view.distance_input.setText(test_value)
    assert view.distance_input.text() == test_value



import cv2 as cv
import numpy as np
import os, sys
from PySide6.QtCore import QMetaObject, Qt, QTimer, QThread, Signal, QObject
from arcjetCV.utils.utils import clahe_normalize, annotate_image_with_frame_number
from arcjetCV.utils.output import OutputListJSON
from arcjetCV.utils.video import Video

try:
    from arcjetCV.segmentation.contour.contour import (
        contoursHSV,
        contoursGRAY,
        contoursCNN,
        getEdgeFromContour,
        contoursAutoHSV,
        getPoints,
    )
    from arcjetCV.segmentation.contour.cnn import CNN

    _contour_import_error = None
except ModuleNotFoundError as exc:
    contoursHSV = contoursGRAY = contoursCNN = getEdgeFromContour = None
    contoursAutoHSV = getPoints = None
    CNN = None
    _contour_import_error = exc


class ProcessorWorker(QObject):
    """Worker class that runs ArcjetProcessor in a separate thread."""

    progress_updated = Signal(int)  # Signal for updating the progress bar
    finished = Signal()  # Signal for when processing is done

    def __init__(
        self,
        processor,
        video,
        options,
        first_frame,
        last_frame,
        frame_stride,
        output_prefix,
        write_json,
        write_video,
        display_shock,
    ):
        super().__init__()
        self.processor = processor
        self.video = video
        self.options = options
        self.first_frame = first_frame
        self.last_frame = last_frame
        self.frame_stride = frame_stride
        self.output_prefix = output_prefix
        self.write_json = write_json
        self.write_video = write_video
        self.display_shock = display_shock
        self.processing_done = False

    def run(self):
        """Run video processing in a separate thread, consistent with ArcjetProcessor.process_all()."""
        try:
            if not self.output_prefix:
                self.output_prefix = "output"  # Ensure filename is valid

            # Ensure output filename is correctly formatted
            json_filename = (
                f"{self.output_prefix}_{self.first_frame}_{self.last_frame}.json"
            )
            json_path = os.path.join(self.video.folder, json_filename)

            out_json = OutputListJSON(json_path)

            total_frames = max(
                1, (self.last_frame - self.first_frame) // self.frame_stride + 1
            )
            processed_frames = 0

            # Initialize video writer if necessary
            if self.write_video:
                video_output_name = f"video_out_{self.output_prefix}_{self.first_frame}_{self.last_frame}.m4v"
                self.video.get_writer(video_output_name)

            # Process frames
            for frame_index in range(
                self.first_frame, self.last_frame + 1, self.frame_stride
            ):
                frame = self.video.get_frame(frame_index)
                if frame is None:
                    print(f"Warning: Skipped frame {frame_index}")
                    continue

                # Process the frame
                self.options["INDEX"] = frame_index
                contour_dict, argdict = self.processor.process(frame, self.options)
                argdict["PIXELS_PER_MM"] = self.processor.pixels_per_mm
                argdict.update(contour_dict)
                out_json.append(argdict.copy())

                # Handle video writing
                if self.write_video:
                    # Draw detected contours on output video frames.
                    width = frame.shape[1]
                    thickness = max(1, width // 500)

                    model_contours = contour_dict.get("MODEL")
                    if model_contours is not None:
                        cv.drawContours(frame, model_contours, -1, (0, 255, 0), thickness)

                    if self.display_shock:
                        shock_contours = contour_dict.get("SHOCK")
                        if shock_contours is not None:
                            cv.drawContours(
                                frame, shock_contours, -1, (255, 0, 255), thickness
                            )

                    annotate_image_with_frame_number(frame, frame_index)
                    frame = cv.cvtColor(frame, cv.COLOR_BGR2RGB)
                    self.video.writer.write(frame)

                # Emit progress update
                processed_frames += 1
                progress = int((processed_frames / total_frames) * 100)
                self.progress_updated.emit(progress)

            # Ensure progress reaches 100%
            self.progress_updated.emit(100)

            # Write JSON output
            if self.write_json:
                out_json.write()

            # Close video writer if necessary
            if self.write_video:
                self.video.close_writer()

        except Exception as e:
            print(f"Processing failed: {e}")

        # Signal completion
        self.finished.emit()

    def stop(self):
        """Stop the worker safely."""
        print("🛑 Stopping processing thread...")
        self.stop_flag = True


class ArcjetProcessor:
    """
    Video frame processor

    Primary image processing class: used to read in video data, extract leading edges,
    hold processed arrays, and output processed data to file.
    """

    def __init__(self, videometa, progress_bar=None):
        """
        Initializes the ArcjetProcessor object.

        :param videometa: dictionary containing video metadata
        """
        if _contour_import_error is not None:
            raise ModuleNotFoundError(
                "arcjetCV.segmentation.contour is unavailable. "
                "Install the contour segmentation optional dependencies "
                f"({type(_contour_import_error).__name__}: {_contour_import_error})."
            )

        self.flow_dir = videometa["FLOW_DIRECTION"]
        self.h = videometa["HEIGHT"]
        self.w = videometa["WIDTH"]
        self.crop = videometa.crop_range()
        self.cnn = None
        self.pixels_per_mm = videometa.get(
            "PIXELS_PER_MM", 1.0
        )  # ✅ Default to 1.0 if missing
        self.progress_bar = progress_bar
        self.filename = None

    def update_video_meta(self, videometa):
        """
        Updates video metadata.

        :param videometa: dictionary containing updated video metadata
        """
        self.flow_dir = videometa["FLOW_DIRECTION"]
        self.h = videometa["HEIGHT"]
        self.w = videometa["WIDTH"]
        self.crop = videometa.crop_range()

    def get_flow_direction(self, frame):
        """
        Infers flow direction from the provided frame.

        :param frame: opencv image
        :returns flowDirection: string, "left or "right"
        TODO: add support for top/bottom directions
        """
        if len(frame.shape) == 3:
            gray = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
        else:
            gray = frame

        # smooth image to remove speckles/text
        gray = cv.GaussianBlur(gray, (15, 15), 0)

        # find location of max intensity
        _, _, _, max_loc = cv.minMaxLoc(gray)
        width_img, width_loc = frame.shape[1], max_loc[1]
        flux_loc = width_loc / width_img

        # Bright location generally indicates flow direction
        if flux_loc > 0.5:
            flow_direction = "left"
        elif flux_loc < 0.5:
            flow_direction = "right"

        return flow_direction

    def get_image_flags(self, frame, argdict):
        """
        Uses histogram of 8-bit grayscale image (0,255) to classify image type.

        :param frame: opencv image
        :param argdict: dictionary to store flags
        :returns: dictionary of flags
        """
        try:
            # Attempt to retrieve the model fraction value from argdict, defaults to 0.005 if not found
            modelfraction = argdict["MODEL_FRACTION"]
        except KeyError:
            modelfraction = 0.005

        ### Gray value histogram
        # Convert the input image to grayscale
        gray_ = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
        # Apply Gaussian blur to the grayscale image to reduce noise for better analysis
        gray = cv.GaussianBlur(gray_, (5, 5), 0)
        # Store the minimum and maximum pixel values of the grayscale image in argdict
        argdict["PIXEL_MIN"] = gray.min()
        argdict["PIXEL_MAX"] = gray.max()

        ### grayscale histogram
        histr = cv.calcHist([gray], None, None, [256], (0, 256))
        imgsize = gray.size

        ### classification criteria

        # bright pixels occupy more than one histogram bin (not a single shade)
        modelvis = ((histr[12:250] / imgsize) > 0.00).sum() != 1
        # bright pixels exceed a threshold fraction of the full image
        modelvis *= (histr[50:250].sum() / imgsize) > modelfraction
        argdict["MODEL_VISIBLE"] = modelvis

        argdict["OVEREXPOSED"] = (histr[243:].sum() / imgsize) > modelfraction
        argdict["UNDEREXPOSED"] = histr[150:].sum() / imgsize < modelfraction
        return argdict

    def segment(self, img_crop, argdict):
        """
        Segments image using one of several methods specified in argdict.

        :param img_crop: cropped opencv image
        :param argdict: dictionary containing segmentation method and related parameters
        :returns: contour_dict: dictionary containing contours
                flags: dictionary containing flags
        """

        # Check the segmentation method specified in argdict and execute the corresponding block
        if argdict["SEGMENT_METHOD"] == "AutoHSV":
            # If the method is AutoHSV, call the contoursAutoHSV function with the cropped image
            contour_dict, flags = contoursAutoHSV(img_crop, flags=argdict)

        elif argdict["SEGMENT_METHOD"] == "HSV":
            # If the method is HSV, first try to retrieve HSV range values from argdict
            try:
                self.HSVModelRange = argdict["HSV_MODEL_RANGE"]
                self.HSVShockRange = argdict["HSV_SHOCK_RANGE"]
            except KeyError:
                # If the ranges are not specified, use default values and print a message
                self.HSVModelRange = [(0, 0, 150), (121, 125, 255)]
                self.HSVShockRange = [(125, 40, 85), (170, 80, 230)]
                print(
                    f"HSVRange not provided, using default value of self.HSVModelRange: {self.HSVModelRange}, self.HSVShockRange: {self.HSVShockRange}"
                )
            # Normalize the cropped image for better segmentation
            img_clahe = clahe_normalize(img_crop)
            # Call the contoursHSV function with the normalized image and HSV ranges
            contour_dict, flags = contoursHSV(
                img_clahe,
                log=None,
                minHSVModel=self.HSVModelRange[0],
                maxHSVModel=self.HSVModelRange[1],
                minHSVShock=self.HSVShockRange[0],
                maxHSVShock=self.HSVShockRange[1],
            )

        elif argdict["SEGMENT_METHOD"] == "GRAY":
            # If the method is GRAY, try to retrieve the threshold value from argdict
            try:
                thresh = argdict["THRESHOLD"]
            except:
                # Use a default threshold if not specified and print a message
                thresh = 240
                print(f"Threshold not provided, using default value of {thresh}")
            # Normalize the cropped image
            img_clahe = clahe_normalize(img_crop)
            # Call the contoursGRAY function with the normalized image and the threshold
            contour_dict, flags = contoursGRAY(img_clahe, thresh=thresh, log=None)

        elif argdict["SEGMENT_METHOD"] == "CNN":
            # If the method is CNN, call the contoursCNN function with the cropped image and the CNN model
            if self.cnn is None:
                try:
                    self.cnn = CNN()
                except Exception as exc:
                    raise RuntimeError(
                        "CNN segmentation model could not be loaded. "
                        "Install valid CNN checkpoints and keep Filter Method='CNN'."
                    ) from exc
            contour_dict, flags = contoursCNN(img_crop, self.cnn)

        else:
            # If none of the specified methods match, return None to indicate failure
            return

        # Update the original argdict with the flags returned from the segmentation function
        argdict.update(flags)
        # Return the dictionary of contours and the updated argdict
        return contour_dict, argdict

    def get_edges_metrics(self, contour_dict, argdict, offset):
        """
        Retrieves edges and metrics from contour dictionary.

        :param contour_dict: dictionary containing contours
        :param argdict: dictionary containing metrics
        :param offset: tuple containing offset values
        :returns: edges: dictionary containing edges
                  argdict: updated dictionary containing metrics
        """
        edges = {}
        for key in contour_dict.keys():
            c = contour_dict[key]

            if c is not None and len(c) > 0:
                ### get contour area
                M = cv.moments(c)
                argdict[key + "_AREA"] = M["m00"]

                ### get centroid
                if M["m00"] > 0:
                    argdict[key + "_CENTROID_X"] = int(M["m10"] / M["m00"])
                    argdict[key + "_CENTROID_Y"] = int(M["m01"] / M["m00"])
                else:
                    argdict[key + "_CENTROID_X"] = np.nan
                    argdict[key + "_CENTROID_Y"] = np.nan

                ### get front edge
                edges[key] = getEdgeFromContour(
                    c,
                    self.flow_dir,
                    offset=(self.crop[0][0] - offset[0], self.crop[1][0] - offset[1]),
                )

                if len(edges[key]) > 0:
                    if key == "MODEL":
                        outputs = getPoints(
                            edges[key],
                            flow_direction=self.flow_dir,
                            r=[-0.95, -0.50, 0, 0.50, 0.95],
                            prefix="MODEL",
                        )
                    else:  # SHOCK
                        outputs = getPoints(
                            edges[key],
                            flow_direction=self.flow_dir,
                            r=[0],
                            prefix="SHOCK",
                        )
                    argdict.update(outputs)
            else:
                edges[key] = None
        return edges, argdict

    def make_crop_square(self, frame):
        """
        Makes the provided frame square by cropping or padding.

        :param frame: opencv image
        :returns: square_frame: square opencv image
                  offset: list containing offset values
        """
        # Crop the frame based on predefined crop coordinates stored in self.crop
        # self.crop is expected to be a tuple or list with two elements, each an (start, end) pair for y and x dimensions respectively
        cropped_frame = frame[
            self.crop[0][0] : self.crop[0][1], self.crop[1][0] : self.crop[1][1]
        ]

        # Check if the cropped frame is grayscale (i.e., has only one channel)
        if len(cropped_frame.shape) == 2 or cropped_frame.shape[2] == 1:
            # Convert grayscale to RGB
            cropped_frame = cv.cvtColor(cropped_frame, cv.COLOR_GRAY2RGB)

        # Determine the height and width of the cropped frame
        cropped_height, cropped_width = cropped_frame.shape[:2]

        # Calculate the side length of the new square frame as the max of cropped height and width
        square_side = max(cropped_height, cropped_width)

        # Initialize a square frame filled with zeros (black) of the same type as the cropped frame
        square_frame = np.zeros(
            (square_side, square_side, 3), dtype=cropped_frame.dtype
        )

        # Calculate starting points (y, x) to paste the cropped frame into the square frame
        # so that it is centered within the square frame
        start_y = (square_side - cropped_height) // 2
        start_x = (square_side - cropped_width) // 2

        # Paste the cropped frame into the square frame at the calculated starting points
        square_frame[
            start_y : start_y + cropped_height, start_x : start_x + cropped_width
        ] = cropped_frame

        # Return the square frame along with the offset values indicating where the cropped frame
        # was placed within the square frame
        return square_frame, [start_y, start_x]

    def process(self, frame, argdict):
        """
        Processes the given frame.

        :param frame: opencv image
        :param argdict: dictionary containing segmentation parameters
        :returns: edges: dictionary containing edges
                  argdict: updated dictionary containing metrics

        Example:
        ```python
        processor = ArcjetProcessor(videometa)
        frame = cv.imread('frame.jpg')
        argdict = {"SEGMENT_METHOD": "AutoHSV", "MODEL_FRACTION": 0.005}
        edges, argdict = processor.process(frame, argdict)
        ```
        """
        # Determine the flow direction of the frame if not already set
        if self.flow_dir is None:
            self.flow_dir = self.get_flow_direction(frame)

        # Make the frame square to ensure consistent processing, obtaining the cropped frame and offset
        frame_crop, offset = self.make_crop_square(frame)

        # Update argdict with image flags based on the cropped frame
        argdict = self.get_image_flags(frame_crop, argdict)

        # Segment the cropped frame, updating argdict with segmentation results
        contour_dict, argdict = self.segment(frame_crop, argdict)

        # Calculate edge metrics based on contours, updating argdict further
        edges, argdict = self.get_edges_metrics(contour_dict, argdict, offset)

        # Return the edges and a copy of the updated argdict
        return edges, argdict.copy()

    def process_all(
        self,
        video: Video,
        options,
        first_frame,
        last_frame,
        frame_stride,
        output_prefix="",
        write_json=True,
        write_video=False,
        display_shock=True,
    ):
        """
        Processes all frames in the video.

        :param video: video object (defined in utils/video.py)
        :param options: dictionary containing segmentation options
        :param first_frame: index of the first frame to process
        :param last_frame: index of the last frame to process
        :param frame_stride: stride for frame processing
        :param write_json: boolean indicating whether to write processed data to JSON file
        :param write_video: boolean indicating whether to write processed video

        Example:
        ```python
        video = Video('input_video.mp4')
        options = {"SEGMENT_METHOD": "AutoHSV", "MODEL_FRACTION": 0.005}
        processor = ArcjetProcessor(videometa)
        processor.process_all(video, options, 0, 100, 1, 'output.json', write_video=True)
        ```
        """

        # Initialize video writer if write_video is True
        if write_video:

            video_output_name = "video_out_%s_%i_%i.m4v" % (
                output_prefix,
                first_frame,
                last_frame,
            )
            video.get_writer(video_output_name)

        # Setup output JSON file
        if output_prefix == "":
            output_prefix = video.name
        self.filename = "%s_%i_%i.json" % (output_prefix, first_frame, last_frame)
        out_json = OutputListJSON(os.path.join(video.folder, self.filename))

        # Iterate over frames from first_frame to last_frame, with steps of frame_stride
        for frame_index in range(first_frame, last_frame + 1, frame_stride):
            try:
                frame = video.get_frame(frame_index)

                # If a frame cannot be retrieved, print an error message and return
                if frame is None:
                    print(f"Failed at frame {frame_index}")
                    continue

                # Update options with the current frame index
                options["INDEX"] = frame_index

                # Process the current frame, obtaining contours and updated argdict
                contour_dict, argdict = self.process(frame, options)

                # Add pixels_per_mm to the output dictionary
                argdict["PIXELS_PER_MM"] = self.pixels_per_mm

                # Draw model contour always; draw shock only when enabled.
                width = frame.shape[1]
                thickness = max(1, width // 500)

                model_contours = contour_dict.get("MODEL")
                if model_contours is not None:
                    cv.drawContours(frame, model_contours, -1, (0, 255, 0), thickness)

                if display_shock:
                    shock_contours = contour_dict.get("SHOCK")
                    if shock_contours is not None:
                        cv.drawContours(
                            frame, shock_contours, -1, (255, 0, 255), thickness
                        )

                # Annotate the frame with its index for reference
                annotate_image_with_frame_number(frame, frame_index)
                argdict.update(contour_dict)

                # update output dictionary
                out_json.append(argdict.copy())

                # Add processed frame to video output
                if write_video:
                    frame = cv.cvtColor(frame, cv.COLOR_BGR2RGB)
                    video.writer.write(frame)
                    # ✅ Calculate progress
                progress_percentage = int(
                    min(
                        (
                            (((frame_index - first_frame) / frame_stride) + 1)
                            / np.ceil((last_frame - first_frame + 1) / frame_stride)
                        )
                        * 100,
                        100,
                    )
                )

                # ✅ Update Progress Bar if it exists
                if self.progress_bar:
                    QTimer.singleShot(
                        0, lambda: self.progress_bar.setValue(progress_percentage)
                    )

                # ✅ Print progress in the terminal (for debugging)
                sys.stdout.write(
                    f"\rProcessing video using {options['SEGMENT_METHOD']} ... {progress_percentage}%"
                )

                # # Print processing progress
                # sys.stdout.write(
                #     f"\rProcessing video using {options['SEGMENT_METHOD']} ... "
                #     + f"{min(((((frame_index - first_frame) / frame_stride) + 1) / np.ceil((last_frame - first_frame + 1) / frame_stride)) * 100, 100):.1f}%"
                # )
            except Exception as e:
                print(f"Failed at frame {frame_index} with error:\n" + str(e))
        # ✅ Ensure progress reaches 100% at the end
        if self.progress_bar:
            QMetaObject.invokeMethod(
                self.progress_bar, "setValue", Qt.QueuedConnection, 100
            )

        if write_json:
            out_json.write()

        if write_video:
            video.close_writer()

        return out_json



import unittest
import cv2 as cv
import numpy as np
from arcjetCV.segmentation.contour.contour import contoursCNN, contoursAutoHSV, contoursGRAY, contoursHSV
from unittest.mock import patch


class TestContoursGRAY(unittest.TestCase):

    def test_no_contours(self):
        """Test that the function returns the appropriate flag when no contours are found."""
        # Create a blank 100x100 black image.
        img = np.zeros((100, 100, 3), dtype=np.uint8)

        contour_dict, flags = contoursGRAY(img, 150)
        self.assertIsNone(contour_dict['MODEL'])
        self.assertTrue(flags['MODEL_CONTOUR_FAILED'])

    def test_find_contour(self):
        """Test that the function correctly finds and returns the contour of a white rectangle."""
        # Create a 100x100 black image with a white rectangle in the center.
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        cv.rectangle(img, (25, 25), (95, 95), (255, 255, 255), -1)

        contour_dict, flags = contoursGRAY(img, 150)
        self.assertIsNotNone(contour_dict['MODEL'])
        self.assertFalse(flags['MODEL_CONTOUR_FAILED'])

    def test_left_edge_of_rectangle(self):
        # Create a synthetic overexposed image (10 everywhere except a rectangle of value 100)
        img = np.ones((500, 500, 3), dtype=np.uint8) * 10
        cv.rectangle(img, (150, 150), (350, 350), (100, 100, 100), -1)

        # Use the contoursGRAY function
        contour_dict, flags = contoursGRAY(img, thresh=50)

        # Get the bounding rectangle of the detected contour
        x, y, w, h = cv.boundingRect(contour_dict['MODEL'])

        # Assert that the left edge of the bounding rectangle matches the rectangle's left edge in the synthetic image
        self.assertEqual(x, 150)

    def test_log_message(self):
        """Test that a message is written to the log when no contours are found."""
        # Mock a simple log object with a write method
        class MockLog:
            def __init__(self):
                self.messages = []

            def write(self, msg):
                self.messages.append(msg)

        mock_log = MockLog()

        # Create a blank 100x100 black image.
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        _, _ = contoursGRAY(img, 150, log=mock_log)
        
        # Check if the appropriate message was written to the log.
        self.assertTrue('no GRAY model contours found at thresh==150' in mock_log.messages)

class TestContoursAutoHSV(unittest.TestCase):

    def test_contour_detection_using_HSV(self):
        # Create a synthetic image with a clearly defined model rectangle and shock rectangle
        img = np.ones((500, 500, 3), dtype=np.uint8) * 10

        # Add synthetic model rectangle (HSV: roughly (160, 50, 220))
        cv.rectangle(img, (150, 150), (350, 350), (206, 177, 220), -1)

        # Add synthetic shock rectangle (HSV: roughly (135, 100, 220))
        cv.rectangle(img, (100, 100), (125, 400), (220, 134, 177), -1)

        # Use the contoursAutoHSV function
        contour_dict, flags = contoursAutoHSV(img)

        # Check if MODEL contour is detected
        self.assertIsNotNone(contour_dict['MODEL'])

        # Check if SHOCK contour is detected
        self.assertIsNotNone(contour_dict['SHOCK'])

        # Check if the bounding rectangle of the detected MODEL contour matches the known position
        x, y, w, h = cv.boundingRect(contour_dict['MODEL'])
        self.assertEqual((x, y, w, h), (150, 150, 201, 201))

        # Check if the bounding rectangle of the detected SHOCK contour matches the known position
        x, y, w, h = cv.boundingRect(contour_dict['SHOCK'])
        self.assertEqual((x, y, w, h), (100, 100, 26, 301))

class TestContoursHSV(unittest.TestCase):

    def test_distinct_regions(self):
        # Create a synthetic image with distinct model and shock regions
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        # Model region in BGR
        img[25:95, 25:95] = (220, 177, 134) 
        # Shock region in BGR
        img[10:20, 10:20] = (220,  65, 142) 
        contours, flags = contoursHSV(img)

        # Ensure that the model and shock contours are detected
        self.assertIsNotNone(contours['MODEL'])
        self.assertIsNotNone(contours['SHOCK'])

    def test_no_regions(self):
        # Create a blank image
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        contours, flags = contoursHSV(img)

        # Ensure that no model or shock contours are detected
        self.assertIsNone(contours['MODEL'])
        self.assertIsNone(contours['SHOCK'])
        self.assertTrue(flags['MODEL_CONTOUR_FAILED'])
        self.assertTrue(flags['SHOCK_CONTOUR_FAILED'])

    def test_only_model(self):
        # Create an image with only model region
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        img[25:95, 25:95] = (220, 177, 134) # Model region in BGR
        contours, flags = contoursHSV(img)

        # Ensure that only the model contour is detected
        self.assertIsNotNone(contours['MODEL'])
        self.assertIsNone(contours['SHOCK'])
        self.assertFalse(flags['MODEL_CONTOUR_FAILED'])
        self.assertTrue(flags['SHOCK_CONTOUR_FAILED'])

    def test_only_shock(self):
        # Create an image with only shock region
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        img[10:20, 10:20] = (220,  65, 142) # Shock region in BGR
        contours, flags = contoursHSV(img)

        # Ensure that only the shock contour is detected
        #self.assertIsNone(contours['MODEL'])
        self.assertIsNotNone(contours['SHOCK'])
        #self.assertTrue(flags['MODEL_CONTOUR_FAILED'])
        self.assertFalse(flags['SHOCK_CONTOUR_FAILED'])

    def test_logging(self):
        class DummyLog:
            def __init__(self):
                self.messages = []
            
            def write(self, msg):
                self.messages.append(msg)

        log = DummyLog()
        # Create a blank image
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        contours, flags = contoursHSV(img, log=log)

        # Ensure that appropriate log messages are written
        self.assertIn('no shock contours found', log.messages)

    def test_matching_rectangle_model(self):
        # Create an image with only model region
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        x, y, w, h = 25, 25, 50, 50
        img[y:y+h, x:x+w] = (220, 177, 134)  # Model region in BGR
        contours, flags = contoursHSV(img)

        # Ensure that the model contour's bounding box matches the synthetic rectangle
        rect = cv.boundingRect(contours['MODEL'])
        self.assertEqual(rect, (x, y, w, h))

    def test_matching_rectangle_shock(self):
        # Create an image with only shock region
        img = np.zeros((100, 100, 3), dtype=np.uint8)
        x, y, w, h = 25, 25, 50, 50
        img[y:y+h, x:x+w] = (220,  65, 142)  # Shock region in BGR
        contours, flags = contoursHSV(img)

        # Ensure that the shock contour's bounding box matches the synthetic rectangle
        rect = cv.boundingRect(contours['SHOCK'])
        self.assertEqual(rect, (x+1, y+1, w-2, h-2))

class TestContoursCNN(unittest.TestCase):

    def mock_cnn_apply(img, model):
        # This mocked CNN application creates a synthetic mask
        # 0: background, 1: model, 2: shock
        mask = np.zeros((100, 100))
        mask[25:95, 25:95] = 1  # model region
        mask[10:20, 10:20] = 2  # shock region
        return mask

    # @patch('utils.Functions.cnn_apply', side_effect=mock_cnn_apply)
    # def test_contoursCNN(self, mock_cnn_apply_func):
    #     # Create a synthetic image
    #     img = np.zeros((100, 100, 3), dtype=np.uint8)
    #     model = None  # For the sake of this test, the model doesn't matter because cnn_apply is mocked
    #     contours, flags = contoursCNN(img, model)

    #     # Ensure model contour matches the synthetic region
    #     model_rect = cv.boundingRect(contours['MODEL'])
    #     self.assertEqual(model_rect, (25, 25, 50, 50))

    #     # Ensure shock contour matches the synthetic region
    #     shock_rect = cv.boundingRect(contours['SHOCK'])
    #     self.assertEqual(shock_rect, (10, 10, 10, 10))
        

if __name__ == '__main__':
    unittest.main()



import urllib.request
from pathlib import Path
import os
import hashlib
from PySide6.QtWidgets import (
    QApplication,
    QMessageBox,
    QDialog,
    QVBoxLayout,
    QLabel,
    QProgressBar,
)
from PySide6.QtCore import Qt, QThread, Signal


# -------------------- CONFIG --------------------

MODEL_NAME = "Unet-xception_25_weights_only.pt"
MODEL_URL = "https://github.com/magnus-haw/arcjetCV/raw/main/arcjetCV/segmentation/contour/Unet-xception_25_weights_only.pt"
EXPECTED_HASH = "adcfd0e04c51be32b69e8ab1139c172df8c3e9c2fc85844db2c8926240631171"


# -------------------- SHA256 CHECK --------------------


def verify_sha256(path: Path, expected_hash: str) -> bool:
    if not path.exists():
        return False
    h = hashlib.sha256()
    with path.open("rb") as f:
        for chunk in iter(lambda: f.read(8192), b""):
            h.update(chunk)
    return h.hexdigest() == expected_hash


# -------------------- BACKGROUND DOWNLOAD THREAD --------------------


class DownloadThread(QThread):
    progress = Signal(int)
    error = Signal(str)
    finished = Signal()

    def __init__(self, url, output_path):
        super().__init__()
        self.url = url
        self.output_path = output_path

    def run(self):
        try:

            def reporthook(blocknum, blocksize, totalsize):
                readsofar = blocknum * blocksize
                percent = int(readsofar * 100 / totalsize) if totalsize > 0 else 0
                self.progress.emit(min(percent, 100))

            urllib.request.urlretrieve(self.url, self.output_path, reporthook)
            self.finished.emit()
        except Exception as e:
            self.error.emit(str(e))


# -------------------- POPUP WIDGET --------------------


class DownloadPopup(QDialog):
    def __init__(self, url, output_path):
        super().__init__()
        self.setWindowTitle("Downloading Model Weights")
        self.setWindowFlags(self.windowFlags() | Qt.CustomizeWindowHint)
        self.setWindowFlags(self.windowFlags() & ~Qt.WindowCloseButtonHint)

        self.layout = QVBoxLayout()
        self.label = QLabel("Downloading model weights, please wait...")
        self.progress_bar = QProgressBar()
        self.progress_bar.setRange(0, 100)
        self.layout.addWidget(self.label)
        self.layout.addWidget(self.progress_bar)
        self.setLayout(self.layout)

        self.thread = DownloadThread(url, output_path)
        self.thread.progress.connect(self.progress_bar.setValue)
        self.thread.error.connect(self.show_error)
        self.thread.finished.connect(self.accept)
        self.thread.start()

    def show_error(self, message):
        QMessageBox.critical(self, "Download Failed", f"❌ {message}")
        self.reject()


# -------------------- MAIN FUNCTION --------------------


def get_model_checkpoint():
    checkpoint_path = Path(__file__).parent / MODEL_NAME

    # If file doesn't exist or hash is incorrect, download
    if not verify_sha256(checkpoint_path, EXPECTED_HASH):
        app = QApplication.instance() or QApplication([])
        popup = DownloadPopup(MODEL_URL, str(checkpoint_path))
        if not popup.exec():
            raise RuntimeError("Download canceled or failed.")

        if not verify_sha256(checkpoint_path, EXPECTED_HASH):
            raise RuntimeError("Download failed or file corrupted (hash mismatch).")

    return checkpoint_path



from PySide6.QtWidgets import QApplication
from calibration_controller import CalibrationController
from calibration_view import CalibrationView
import sys


def main():
    app = QApplication(sys.argv)
    view = CalibrationView()
    controller = CalibrationController(view)
    view.show()
    sys.exit(app.exec())


if __name__ == "__main__":
    main()



from PySide6.QtWidgets import (
    QWidget,
    QVBoxLayout,
    QHBoxLayout,
    QPushButton,
    QLabel,
    QLineEdit,
    QGroupBox,
    QTabWidget,
    QComboBox,
    QSizePolicy,
    QSpinBox,
    QDoubleSpinBox,
)
from PySide6.QtCore import Qt
from matplotlib.backends.backend_qtagg import FigureCanvasQTAgg as FigureCanvas
from matplotlib.figure import Figure
import matplotlib.image as mpimg
import os
from pathlib import Path


class CalibrationView(QWidget):
    def __init__(self):
        super().__init__()

        # Main layout: horizontal
        main_layout = QHBoxLayout()

        # Left side: Matplotlib canvas
        self.figure = Figure()
        self.canvas = FigureCanvas(self.figure)
        canvas_layout = QVBoxLayout()
        canvas_layout.addWidget(self.canvas)
        main_layout.addLayout(canvas_layout, stretch=3)

        # Right side: buttons and inputs
        button_layout = QVBoxLayout()

        # # Pattern Calibration Section
        # self.pattern_calibration_group = QGroupBox("1. Intrinsic Calibration")
        # self.pattern_calibration_layout = QVBoxLayout()

        # # Adding Pattern Calibration Buttons
        self.print_button = QPushButton("Print Chessboard")

        # grid_size_layout_1 = QHBoxLayout()
        # label_layout_1 = QHBoxLayout()  # Layout for aligning labels on the left

        # grid_size_label_1 = QLabel("Pattern Size:")

        # # Ensure labels stay on the left
        # label_layout_1.addWidget(grid_size_label_1)
        # label_layout_1.addStretch()  # Push elements to the left

        # # Spinboxes for grid size input
        # self.grid_rows_input_1 = QSpinBox()
        # self.grid_cols_input_1 = QSpinBox()

        # # Configure QSpinBox properties
        # self.grid_rows_input_1.setMinimum(1)
        # self.grid_rows_input_1.setMaximum(100)
        # self.grid_rows_input_1.setValue(9)

        # self.grid_cols_input_1.setMinimum(1)
        # self.grid_cols_input_1.setMaximum(100)
        # self.grid_cols_input_1.setValue(4)

        # # Ensure QSpinBox fields expand properly
        # self.grid_rows_input_1.setSizePolicy(
        #     QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        # )
        # self.grid_cols_input_1.setSizePolicy(
        #     QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        # )

        # # Add elements to the grid size layout
        # grid_size_layout_1.addLayout(label_layout_1)
        # grid_size_layout_1.addWidget(
        #     QLabel("Cols:"), alignment=Qt.AlignmentFlag.AlignRight
        # )
        # grid_size_layout_1.addWidget(self.grid_cols_input_1, stretch=1)

        # grid_size_layout_1.addWidget(
        #     QLabel("Rows:"), alignment=Qt.AlignmentFlag.AlignRight
        # )
        # grid_size_layout_1.addWidget(self.grid_rows_input_1, stretch=1)

        # self.load_button = QPushButton("Load Calibration Images")
        # self.calibrate_button = QPushButton("Calibrate Camera")
        # self.image_label = QLabel("No images loaded")

        # self.pattern_calibration_layout.addWidget(self.print_button)
        # self.pattern_calibration_layout.addLayout(grid_size_layout_1)
        # self.pattern_calibration_layout.addWidget(self.load_button)
        # self.pattern_calibration_layout.addWidget(self.calibrate_button)
        # self.pattern_calibration_layout.addWidget(self.image_label)
        # self.pattern_calibration_group.setLayout(self.pattern_calibration_layout)

        # button_layout.addWidget(self.pattern_calibration_group)
        # button_layout.addSpacing(20)

        # Image Resolution Section
        self.image_resolution_group = QGroupBox()  # "2. Metric Calibration")
        self.image_resolution_layout = QVBoxLayout()

        self.resolution_tabs = QTabWidget()
        self.image_resolution_layout.addWidget(self.resolution_tabs)

        # Pattern Resolution Tab
        self.pattern_resolution_tab = QWidget()
        pattern_resolution_layout = QVBoxLayout()
        self.pattern_resolution_tab.setLayout(pattern_resolution_layout)
        self.resolution_tabs.addTab(self.pattern_resolution_tab, "Pattern Resolution")

        # 1. Grid Size Input
        grid_size_layout = QHBoxLayout()
        label_layout = QHBoxLayout()  # Layout for aligning labels on the left

        grid_size_label_n = QLabel("1.")
        grid_size_label = QLabel("Pattern Size:")

        # Ensure labels stay on the left
        label_layout.addWidget(grid_size_label_n)
        label_layout.addWidget(grid_size_label)
        label_layout.addStretch()  # Push elements to the left

        # Spinboxes for grid size input
        self.grid_rows_input = QSpinBox()
        self.grid_cols_input = QSpinBox()

        # Configure QSpinBox properties
        self.grid_rows_input.setMinimum(1)
        self.grid_rows_input.setMaximum(100)
        self.grid_rows_input.setValue(9)

        self.grid_cols_input.setMinimum(1)
        self.grid_cols_input.setMaximum(100)
        self.grid_cols_input.setValue(4)

        # Ensure QSpinBox fields expand properly
        self.grid_rows_input.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )
        self.grid_cols_input.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )

        # Add elements to the grid size layout
        grid_size_layout.addLayout(label_layout)
        grid_size_layout.addWidget(
            QLabel("Cols:"), alignment=Qt.AlignmentFlag.AlignRight
        )
        grid_size_layout.addWidget(self.grid_cols_input, stretch=1)

        grid_size_layout.addWidget(
            QLabel("Rows:"), alignment=Qt.AlignmentFlag.AlignRight
        )
        grid_size_layout.addWidget(self.grid_rows_input, stretch=1)

        pattern_resolution_layout.addLayout(grid_size_layout)

        # 2. Load Image for Resolution Measurement
        load_image_layout_pattern = QHBoxLayout()
        load_image_layout_pattern.setContentsMargins(0, 0, 0, 0)
        load_image_label_pattern = QLabel("2.")
        self.load_image_button_pattern = QPushButton("Load Calibration Image")
        self.load_image_button_pattern.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )

        load_image_layout_pattern.addWidget(load_image_label_pattern)
        load_image_layout_pattern.addWidget(self.load_image_button_pattern, stretch=1)
        pattern_resolution_layout.addLayout(load_image_layout_pattern)

        # 3. Diagonal Distance Line
        diagonal_distance_layout = QHBoxLayout()
        diagonal_distance_layout.setContentsMargins(
            0, 0, 0, 0
        )  # Remove default margins

        # Left-aligned labels
        label_layout = QHBoxLayout()
        diagonal_distance_label_n = QLabel("3.")
        diagonal_distance_label = QLabel("Diagonal Distance:")

        label_layout.addWidget(diagonal_distance_label_n)
        label_layout.addWidget(diagonal_distance_label)
        label_layout.addStretch()  # Push labels to the left

        # QDoubleSpinBox for diagonal distance input
        self.diagonal_distance_value = QDoubleSpinBox()
        self.diagonal_distance_value.setDecimals(2)  # Allow two decimal places
        self.diagonal_distance_value.setMinimum(0.00)  # Minimum value
        self.diagonal_distance_value.setMaximum(10000.00)  # Maximum value
        self.diagonal_distance_value.setValue(0.00)  # Default value
        self.diagonal_distance_value.setSuffix(" mm")  # Display unit in mm
        self.diagonal_distance_value.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )  # Allow expansion

        # Add elements to the layout
        diagonal_distance_layout.addLayout(label_layout)
        diagonal_distance_layout.addWidget(self.diagonal_distance_value, stretch=1)

        pattern_resolution_layout.addLayout(diagonal_distance_layout)

        # 4. Get Resolution Button
        get_resolution_layout = QHBoxLayout()
        get_resolution_label = QLabel("4.")
        self.get_resolution_button = QPushButton("Calculate Resolution")

        # Ensure button is not too wide and is properly spaced
        self.get_resolution_button.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )

        get_resolution_layout.addWidget(get_resolution_label)
        get_resolution_layout.addWidget(self.get_resolution_button, stretch=1)
        pattern_resolution_layout.addLayout(get_resolution_layout)

        # Ruler Resolution Tab
        self.ruler_resolution_tab = QWidget()
        ruler_resolution_layout = QVBoxLayout()
        self.ruler_resolution_tab.setLayout(ruler_resolution_layout)
        self.resolution_tabs.addTab(self.ruler_resolution_tab, "Ruler Resolution")

        # 1. Load Image for Resolution Measurement
        load_image_layout = QHBoxLayout()
        load_image_layout.setContentsMargins(0, 0, 0, 0)  # Remove default margins
        load_image_label = QLabel("1.")
        self.load_image_button = QPushButton("Load Image for Resolution Measurement")
        self.load_image_button.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )
        load_image_layout.addWidget(load_image_label)
        load_image_layout.addWidget(self.load_image_button, stretch=1)
        ruler_resolution_layout.addLayout(load_image_layout)

        # 2. Draw a Line
        draw_line_layout = QHBoxLayout()
        draw_line_layout.setContentsMargins(0, 0, 0, 0)  # No extra margins for the row
        draw_line_label = QLabel("2.")
        self.instruction_label = QLabel("Draw a line of a known distance on the image")
        self.instruction_label.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )
        draw_line_layout.addWidget(draw_line_label)
        draw_line_layout.addWidget(self.instruction_label, stretch=1)
        ruler_resolution_layout.addLayout(draw_line_layout)

        # 3. Enter Real-World Length
        real_world_length_layout = QHBoxLayout()
        real_world_length_layout.setContentsMargins(
            0, 0, 0, 0
        )  # No extra margins for the row
        real_world_length_label_n = QLabel("3.")
        real_world_length_label = QLabel("Real-World Length:")
        self.distance_input = QLineEdit()
        self.distance_input.setPlaceholderText("Enter real-world length in mm")
        self.distance_input.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )
        real_world_length_layout.addWidget(real_world_length_label_n)
        real_world_length_layout.addWidget(real_world_length_label)
        real_world_length_layout.addWidget(self.distance_input, stretch=1)
        ruler_resolution_layout.addLayout(real_world_length_layout)

        # 4. Calculate Resolution Button
        calculate_resolution_layout = QHBoxLayout()
        calculate_resolution_layout.setContentsMargins(
            0, 0, 0, 0
        )  # No extra margins for the row
        calculate_resolution_label_n = QLabel("4.")
        self.calculate_button = QPushButton("Calculate Resolution")
        self.calculate_button.setSizePolicy(
            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Fixed
        )
        calculate_resolution_layout.addWidget(calculate_resolution_label_n)
        calculate_resolution_layout.addWidget(self.calculate_button)
        ruler_resolution_layout.addLayout(calculate_resolution_layout)

        # Display PPCM Result
        # Inside image_resolution_layout
        self.ppcm_label = QLabel("Calibration Scale: N/A")
        self.image_resolution_layout.addWidget(self.ppcm_label)
        self.ruler_resolution_tab.setLayout(ruler_resolution_layout)

        button_layout.addWidget(self.print_button)

        # Add tabs to the resolution group
        self.image_resolution_group.setLayout(self.image_resolution_layout)
        button_layout.addWidget(self.image_resolution_group)

        # Save Calibration Button
        self.save_calibration_button = QPushButton("Save Calibration")
        button_layout.addWidget(self.save_calibration_button)

        # Add button layout to main layout
        main_layout.addLayout(button_layout, stretch=1)
        self.setLayout(main_layout)
        button_layout.addStretch()

        self.plot_logo()

    def plot_logo(self):
        """Plots the ArcjetCV logo on the Matplotlib canvas."""
        try:
            self.figure.clear()  # Clear the canvas
            ax = self.figure.add_subplot(111)

            # Load the logo
            logo_path = os.path.join(
                Path(__file__).parent.absolute(), "../gui/logo/arcjetCV_logo_white.png"
            )
            logo_image = mpimg.imread(logo_path)

            # Display the logo
            ax.imshow(logo_image)
            ax.axis("off")  # Turn off axes for a cleaner look

            self.canvas.draw()  # Refresh the canvas
        except Exception as e:
            print(f"Error plotting logo: {e}")



import pytest
from arcjetCV.gui.main_window import MainWindow
from PySide6.QtTest import QTest
from PySide6.QtWidgets import QApplication
from PySide6.QtCore import Qt
from pathlib import Path
import os
from PySide6.QtCore import QThread


def find_tests_path():
    project_root = Path(__file__).resolve().parent
    while (
        not (project_root / "setup.py").exists() and project_root.parent != project_root
    ):
        project_root = project_root.parent
    return str(project_root / "tests")


@pytest.fixture
def app(qtbot):
    """Create the main application window and ensure proper cleanup."""
    test_app = QApplication.instance() if QApplication.instance() else QApplication([])
    window = MainWindow()
    window.testing = True
    qtbot.addWidget(window)
    window.hide()

    yield window  # Let the test use the app

    # ✅ Ensure thread cleanup before moving to the next test
    if hasattr(window, "thread") and isinstance(window.thread, QThread):
        if window.thread.isRunning():
            print("Stopping worker thread...")
            window.thread.quit()
            window.thread.wait(5000)

    # ✅ Ensure worker cleanup
    if hasattr(window, "worker") and window.worker is not None:
        window.worker.stop()
        window.worker.deleteLater()
        window.worker = None

    # ✅ Force cleanup of QApplication
    test_app.quit()


def test_main_window_initialization(app):
    assert app.ui.pushButton_loadVideo.text() == "Load Video"


def test_switch_to_extract_edges_tab(app, qtbot):
    target_index = 1  # Updated index after adding the Calibration tab
    tab_bar = app.ui.tabWidget.tabBar()
    tab_rect = tab_bar.tabRect(target_index)
    click_pos = tab_rect.center()
    QTest.mouseClick(tab_bar, Qt.LeftButton, pos=click_pos)
    assert app.ui.tabWidget.currentIndex() == target_index


def test_load_video(app, qtbot, mocker):
    test_switch_to_extract_edges_tab(app, qtbot)  # Ensure we are in the correct tab
    expected_video_path = os.path.join(find_tests_path(), "arcjet_test.mp4")
    mocker.patch(
        "PySide6.QtWidgets.QFileDialog.getOpenFileName",
        return_value=(expected_video_path, ""),
    )

    qtbot.mouseClick(app.ui.pushButton_loadVideo, Qt.LeftButton)

    assert app.path == expected_video_path
    qtbot.mouseClick(app.ui.pushButton_loadVideo, Qt.LeftButton)

    assert app.path == expected_video_path
    assert app.VIDEO_LOADED is True
    assert app.video is not None
    assert app.videometa is not None


def test_select_flow_direction(app, qtbot):
    test_switch_to_extract_edges_tab(app, qtbot)
    flow_direction_text = "left"
    direction_index = app.ui.comboBox_flowDirection.findText(flow_direction_text)
    assert direction_index != -1
    with qtbot.waitSignal(
        app.ui.comboBox_flowDirection.currentIndexChanged, timeout=1000
    ):
        app.ui.comboBox_flowDirection.setCurrentIndex(direction_index)
    assert app.ui.comboBox_flowDirection.currentText() == flow_direction_text


def test_select_filter(app, qtbot):
    test_switch_to_extract_edges_tab(app, qtbot)
    filter_index = app.ui.comboBox_filterType.findText("AutoHSV")
    assert filter_index != -1
    with qtbot.waitSignal(app.ui.comboBox_filterType.currentIndexChanged, timeout=1000):
        app.ui.comboBox_filterType.setCurrentIndex(filter_index)
    assert app.ui.comboBox_filterType.currentIndex() == filter_index


def test_toggle_display_shock(app, qtbot, mocker):
    test_switch_to_extract_edges_tab(app, qtbot)
    initial_state = app.ui.checkBox_display_shock.setChecked(True)
    qtbot.mouseClick(app.ui.checkBox_display_shock, Qt.LeftButton)
    assert app.ui.checkBox_display_shock.isChecked() != initial_state


def test_switch_tabs(app, qtbot):
    """
    Test switching between the Crop, Model Filter, and Shock Filter tabs.
    """
    test_switch_to_extract_edges_tab(app, qtbot)
    crop_tab_index = 0
    model_filter_tab_index = 1
    shock_filter_tab_index = 2

    app.ui.FilterTabs.setCurrentIndex(crop_tab_index)
    assert app.ui.FilterTabs.currentIndex() == crop_tab_index

    app.ui.FilterTabs.setCurrentIndex(model_filter_tab_index)
    assert app.ui.FilterTabs.currentIndex() == model_filter_tab_index

    app.ui.FilterTabs.setCurrentIndex(shock_filter_tab_index)
    assert app.ui.FilterTabs.currentIndex() == shock_filter_tab_index


def test_apply_filter(app, qtbot):
    """
    Test applying a filter.
    """
    test_switch_to_extract_edges_tab(app, qtbot)
    min_hue_value = 10
    max_hue_value = 20

    with qtbot.waitSignals([app.ui.minHue.valueChanged, app.ui.maxHue.valueChanged]):
        app.ui.minHue.setValue(min_hue_value)
        app.ui.maxHue.setValue(max_hue_value)

    assert app.ui.minHue.value() == min_hue_value
    assert app.ui.maxHue.value() == max_hue_value


def test_apply_crop(app, qtbot, mocker):
    """
    Test loading a video and then applying crop settings.
    """
    test_switch_to_extract_edges_tab(app, qtbot)
    expected_video_path = os.path.join(find_tests_path(), "arcjet_test.mp4")
    mocker.patch(
        "PySide6.QtWidgets.QFileDialog.getOpenFileName",
        return_value=(expected_video_path, ""),
    )

    qtbot.mouseClick(app.ui.pushButton_loadVideo, Qt.LeftButton)

    assert app.path == expected_video_path
    assert app.VIDEO_LOADED is True
    assert app.video is not None
    assert app.videometa is not None

    app.ui.spinBox_crop_xmin.setValue(100)
    app.ui.spinBox_crop_xmax.setValue(425)
    app.ui.spinBox_crop_ymin.setValue(10)
    app.ui.spinBox_crop_ymax.setValue(700)

    qtbot.mouseClick(app.ui.applyCrop, Qt.LeftButton)
    expected_crop_settings = [[10, 700], [100, 425]]
    current_crop_settings = app.videometa.crop_range()

    assert (
        current_crop_settings == expected_crop_settings
    ), "Crop settings did not update as expected."


def test_toggle_show_crop_checkbox(app, qtbot, mocker):
    """
    Test the functionality of the 'Show Crop' checkbox.
    """
    test_switch_to_extract_edges_tab(app, qtbot)
    expected_video_path = os.path.join(find_tests_path(), "arcjet_test.mp4")
    mocker.patch(
        "PySide6.QtWidgets.QFileDialog.getOpenFileName",
        return_value=(expected_video_path, ""),
    )

    qtbot.mouseClick(app.ui.pushButton_loadVideo, Qt.LeftButton)

    assert app.path == expected_video_path
    assert app.VIDEO_LOADED is True
    assert app.video is not None
    assert app.videometa is not None
    assert app.ui.checkBox_crop.isChecked()
    qtbot.mouseClick(app.ui.checkBox_crop, Qt.LeftButton)

    assert not app.ui.checkBox_crop.isChecked()
    qtbot.mouseClick(app.ui.checkBox_crop, Qt.LeftButton)
    assert app.ui.checkBox_crop.isChecked()


def test_annotation_checkbox(app, qtbot, mocker):
    test_load_video(app, qtbot, mocker)
    assert app.ui.checkBox_annotate.isChecked()
    qtbot.mouseClick(app.ui.checkBox_annotate, Qt.LeftButton)
    assert not app.ui.checkBox_annotate.isChecked()
    qtbot.mouseClick(app.ui.checkBox_annotate, Qt.LeftButton)
    assert app.ui.checkBox_annotate.isChecked()


def test_apply_model_filter(app, qtbot, mocker):
    """
    Test setting model filter parameters and applying them.
    """
    test_load_video(app, qtbot, mocker)
    filter_index = app.ui.comboBox_filterType.findText("HSV")
    assert filter_index != -1
    with qtbot.waitSignal(app.ui.comboBox_filterType.currentIndexChanged, timeout=1000):
        app.ui.comboBox_filterType.setCurrentIndex(filter_index)
    assert app.ui.comboBox_filterType.currentIndex() == filter_index

    app.ui.minHue.setValue(10)
    app.ui.maxHue.setValue(20)
    app.ui.minSaturation.setValue(30)
    app.ui.maxSaturation.setValue(40)
    app.ui.minIntensity.setValue(50)
    app.ui.maxIntensity.setValue(60)
    app.update_frame_index()
    assert app.processor.HSVModelRange == [(10, 30, 50), (20, 40, 60)]


def test_apply_shock_filter(app, qtbot, mocker):
    """
    Test setting shock filter parameters and applying them.
    """
    test_load_video(app, qtbot, mocker)
    filter_index = app.ui.comboBox_filterType.findText("HSV")
    assert filter_index != -1
    with qtbot.waitSignal(app.ui.comboBox_filterType.currentIndexChanged, timeout=1000):
        app.ui.comboBox_filterType.setCurrentIndex(filter_index)
    assert app.ui.comboBox_filterType.currentIndex() == filter_index

    app.ui.FilterTabs.setCurrentIndex(1)

    app.ui.minHue_2.setValue(70)
    app.ui.maxHue_2.setValue(80)
    app.ui.minSaturation_2.setValue(90)
    app.ui.maxSaturation_2.setValue(100)
    app.ui.minIntensity_2.setValue(110)
    app.ui.maxIntensity_2.setValue(120)
    app.update_frame_index()

    assert app.processor.HSVShockRange == [(70, 90, 110), (80, 100, 120)]


# def test_set_frame_range(app, qtbot, mocker):
#     """
#     Test setting the frame range for processing.
#     """
#     test_load_video(app, qtbot, mocker)
#     app.ui.spinBox_FirstGoodFrame.setValue(150)
#     app.ui.spinBox_LastGoodFrame.setValue(400)
#     # app.process_all()
#     assert app.videometa["FIRST_GOOD_FRAME"] == 150
#     assert app.videometa["LAST_GOOD_FRAME"] == 400
#     # ✅ Ensure all threads are stopped properly after test


def test_process_every_nth_frame(app, qtbot, mocker):
    """
    Test setting the application to process every Nth frame.
    """
    test_load_video(app, qtbot, mocker)
    with qtbot.waitSignal(app.ui.spinBox_frame_skips.valueChanged):
        app.ui.spinBox_frame_skips.setValue(2)
    assert app.ui.spinBox_frame_skips.value() == 2


# def test_set_output_filename_and_process(app, qtbot, mocker):
#     """
#     Test setting the output filename and ensure proper thread cleanup.
#     """
#     test_load_video(app, qtbot, mocker)

#     app.ui.lineEdit_filename.setText("output_filename")

#     # Mock UI message box to avoid popups
#     mocker.patch.object(app, "arcjetcv_message_box", return_value=None)

#     # Start processing
#     app.process_all()

#     # ✅ Wait for the processing thread to finish properly
#     qtbot.waitUntil(lambda: not app.thread.isRunning(), timeout=30000)

#     # ✅ Ensure filename is set after processing
#     assert app.processor.filename == "output_filename_150_400.json"

#     # ✅ Clean up threads after test
#     if hasattr(app, "worker") and app.worker:
#         try:
#             app.worker.stop()
#         except AttributeError:
#             pass  # Some workers may not have a stop method
#         app.worker.deleteLater()
#         app.worker = None

#     if hasattr(app, "thread") and isinstance(app.thread, QThread):
#         if app.thread.isRunning():
#             app.thread.quit()
#             app.thread.wait(5000)

#     app.thread = None


def test_toggle_write_video(app, qtbot, mocker):
    """
    Test toggling the 'Write video' checkbox.
    """
    test_load_video(app, qtbot, mocker)
    initial_state = app.ui.checkBox_writeVideo.isChecked()
    app.ui.checkBox_writeVideo.setChecked(not initial_state)
    assert app.ui.checkBox_writeVideo.isChecked() != initial_state


# Analysis tab


def test_switch_to_analysis_tab(app, qtbot):
    target_index = 2
    tab_bar = app.ui.tabWidget.tabBar()
    tab_rect = tab_bar.tabRect(target_index)
    click_pos = tab_rect.center()
    qtbot.mouseClick(tab_bar, Qt.LeftButton, pos=click_pos)
    assert app.ui.tabWidget.currentIndex() == target_index


def test_load_analysis_files(app, qtbot, mocker):
    expected_file_path = os.path.join(find_tests_path(), "arcjet_test_150_400.json")
    mocker.patch(
        "PySide6.QtWidgets.QFileDialog.getOpenFileNames",
        return_value=([expected_file_path], ""),
    )

    qtbot.mouseClick(app.ui.pushButton_LoadFiles, Qt.LeftButton)

    # ✅ Wait for GUI updates
    qtbot.waitUntil(lambda: app.ui.basebar.text() != "", timeout=5000)

    assert "Finished plotting data" in app.ui.basebar.text()


def test_plot_data_button(app, qtbot, mocker):
    """
    Test the 'Plot Data' button functionality in the 'Analysis' tab after loading analysis files.
    """
    expected_file_path = os.path.join(find_tests_path(), "arcjet_test_150_400.json")
    mocker.patch(
        "PySide6.QtWidgets.QFileDialog.getOpenFileNames",
        return_value=([expected_file_path], ""),
    )

    qtbot.mouseClick(app.ui.pushButton_LoadFiles, Qt.LeftButton)
    qtbot.mouseClick(app.ui.pushButton_PlotData, Qt.LeftButton)

    assert (
        "Plotting data..." in app.ui.basebar.text()
        or "Finished plotting data" in app.ui.basebar.text()
    )


def test_fit_data_button(app, qtbot, mocker):
    """
    Test the 'Fit Data' button functionality in the 'Analysis' tab.
    """
    test_load_analysis_files(app, qtbot, mocker)
    qtbot.mouseClick(app.ui.pushButton_fitData, Qt.LeftButton)
    assert hasattr(app, "fit_dict")
    assert isinstance(app.fit_dict, dict)
    assert app.ui.textBrowser.toPlainText() != ""


def test_export_csv_plots_button(app, qtbot, mocker, tmp_path):
    """
    Test the 'Export CSV/plots' button functionality in the 'Analysis' tab.
    """
    test_load_analysis_files(app, qtbot, mocker)
    mocker.patch(
        "PySide6.QtWidgets.QFileDialog.getExistingDirectory",
        return_value=str(tmp_path),
    )
    qtbot.mouseClick(app.ui.pushButton_export_csv, Qt.LeftButton)
    exported_files = list(tmp_path.glob("*"))
    assert len(exported_files) > 0


def test_switch_to_plotting_params_tab(app, qtbot):
    """
    Test switching to the 'Plotting params' tab within the 'Plotting params' tab.
    """

    app.ui.tabWidget_2.setCurrentIndex(1)
    target_index = 0
    tab_bar = app.ui.tabWidget_2.tabBar()
    tab_rect = tab_bar.tabRect(target_index)
    click_pos = tab_rect.center()

    click_pos.setX(click_pos.x() + tab_bar.geometry().x())
    click_pos.setY(click_pos.y() + tab_bar.geometry().y())

    QTest.mouseClick(tab_bar, Qt.LeftButton, pos=click_pos)

    assert app.ui.tabWidget_2.currentIndex() == target_index


def test_set_length_units(app, qtbot):
    expected_units = "[mm]"
    app.ui.comboBox_units.setCurrentText(expected_units)
    assert app.ui.comboBox_units.currentText() == expected_units


def test_set_frames_per_second(app, qtbot):
    expected_fps = 60.0
    app.ui.doubleSpinBox_fps.setValue(expected_fps)
    assert app.ui.doubleSpinBox_fps.value() == expected_fps


def test_set_mask_nframes(app, qtbot):
    expected_mask_frames = 5
    app.ui.spinBox_mask_frames.setValue(expected_mask_frames)
    assert app.ui.spinBox_mask_frames.value() == expected_mask_frames


def test_toggle_display_shock_2(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_display_shock2.setChecked(True)
    qtbot.mouseClick(app.ui.checkBox_display_shock2, Qt.LeftButton)
    assert app.ui.checkBox_display_shock2.isChecked() != initial_state


def test_switch_to_fitting_params_tab(app, qtbot):
    """
    Test switching to the 'Fitting params' tab within the 'Analysis' tab.
    """
    app.ui.tabWidget.setCurrentIndex(0)
    target_index = 1

    tab_bar = app.ui.tabWidget_2.tabBar()
    tab_rect = tab_bar.tabRect(target_index)
    click_pos = tab_rect.center()

    click_pos.setX(click_pos.x() + tab_bar.geometry().x())
    click_pos.setY(click_pos.y() + tab_bar.geometry().y())

    QTest.mouseClick(tab_bar, Qt.LeftButton, pos=click_pos)

    assert app.ui.tabWidget_2.currentIndex() == target_index


def test_select_fit_type(app, qtbot):
    expected_fit_type = "linear"
    app.ui.comboBox_fit_type.setCurrentText(expected_fit_type)
    assert app.ui.comboBox_fit_type.currentText() == expected_fit_type


def test_set_fit_start_time(app, qtbot):
    expected_start_time = 0.0
    app.ui.doubleSpinBox_fit_start_time.setValue(expected_start_time)
    assert app.ui.doubleSpinBox_fit_start_time.value() == expected_start_time


def test_set_fit_end_time(app, qtbot):
    expected_end_time = 50  # Example end time
    app.ui.doubleSpinBox_fit_last_time.setValue(expected_end_time)
    assert app.ui.doubleSpinBox_fit_last_time.value() == expected_end_time


def test_toggle_checkbox_95_radius(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_95_radius.isChecked()
    qtbot.mouseClick(app.ui.checkBox_95_radius, Qt.LeftButton)
    assert app.ui.checkBox_95_radius.isChecked() != initial_state


def test_toggle_checkbox_m50_radius(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_m50_radius.isChecked()
    qtbot.mouseClick(app.ui.checkBox_m50_radius, Qt.LeftButton)
    assert app.ui.checkBox_m50_radius.isChecked() != initial_state


def test_toggle_checkbox_ypos(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_ypos.isChecked()
    qtbot.mouseClick(app.ui.checkBox_ypos, Qt.LeftButton)
    assert app.ui.checkBox_ypos.isChecked() != initial_state


def test_toggle_checkbox_50_radius(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_50_radius.isChecked()
    qtbot.mouseClick(app.ui.checkBox_50_radius, Qt.LeftButton)
    assert app.ui.checkBox_50_radius.isChecked() != initial_state


def test_toggle_checkbox_shockmodel(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_shockmodel.isChecked()
    qtbot.mouseClick(app.ui.checkBox_shockmodel, Qt.LeftButton)
    assert app.ui.checkBox_shockmodel.isChecked() != initial_state


def test_toggle_checkbox_shock_center(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_shock_center.isChecked()
    qtbot.mouseClick(app.ui.checkBox_shock_center, Qt.LeftButton)
    assert app.ui.checkBox_shock_center.isChecked() != initial_state


def test_toggle_checkbox_model_center(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_model_center.isChecked()
    qtbot.mouseClick(app.ui.checkBox_model_center, Qt.LeftButton)
    assert app.ui.checkBox_model_center.isChecked() != initial_state


def test_toggle_checkbox_m95_radius(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_m95_radius.isChecked()
    qtbot.mouseClick(app.ui.checkBox_m95_radius, Qt.LeftButton)
    assert app.ui.checkBox_m95_radius.isChecked() != initial_state


def test_toggle_checkbox_model_rad(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_model_rad.isChecked()
    qtbot.mouseClick(app.ui.checkBox_model_rad, Qt.LeftButton)
    assert app.ui.checkBox_model_rad.isChecked() != initial_state


def test_toggle_checkbox_shock_area(app, qtbot, mocker):
    test_load_analysis_files(app, qtbot, mocker)
    initial_state = app.ui.checkBox_shock_area.isChecked()
    qtbot.mouseClick(app.ui.checkBox_shock_area, Qt.LeftButton)
    assert app.ui.checkBox_shock_area.isChecked() != initial_state



from setuptools import setup, find_packages
from pathlib import Path
import sys
import os

# Read a long description file that is guaranteed to exist in sdist/wheel builds.
root = Path(__file__).resolve().parent
readme_candidates = [root / "README_pypi.md", root / "README.md"]
for readme_path in readme_candidates:
    if readme_path.exists():
        long_description = readme_path.read_text(encoding="utf-8")
        break
else:
    long_description = "arcjetCV"


def check_linux_dependencies():
    if sys.platform.startswith("linux"):
        print("\n[INFO] Linux detected: Checking required system libraries...")

        # List of required packages
        required_packages = [
            "libxcb-xinerama0",
            "libxcb1",
            "libx11-xcb1",
            "libxcb-cursor0",
            "libxcb-icccm4",
            "libxcb-keysyms1",
            "libxcb-render-util0",
            "libxcb-shape0",
            "libxcb-xfixes0",
            "libxcb-randr0",
            "libxcb-util1",
            "libxcb-image0",
            "libxcb-sync1",
            "libxcb-xinput0",
        ]

        try:
            # Check if running on Ubuntu/Debian
            with open("/etc/os-release") as f:
                os_info = f.read().lower()
            if "ubuntu" in os_info or "debian" in os_info:
                print(
                    "\n[INFO] Ubuntu/Debian detected. Installing dependencies via APT..."
                )
                subprocess.run(["sudo", "apt", "update"], check=True)
                subprocess.run(
                    ["sudo", "apt", "install", "-y"] + required_packages, check=True
                )
                print("\n[INFO] System dependencies installed successfully.")
            else:
                print(
                    "\n[WARNING] Non-Debian system detected. Please install the dependencies manually."
                )
                print(
                    "\n[INFO] Run one of the following commands based on your distribution:"
                )
                print(
                    "\n[Ubuntu/Debian] sudo apt-get install "
                    + " ".join(required_packages)
                )
                print("[Fedora] sudo dnf install libxcb libX11-xcb libxcb-cursor")
                print("[Arch] sudo pacman -S libxcb xcb-util xcb-util-cursor\n")

        except Exception as e:
            print(f"\n[ERROR] Could not determine Linux distribution: {e}")


# Run the platform check before proceeding
check_linux_dependencies()

# Define the setup configuration
setup(
    name="arcjetcv",
    version="1.1.17",  # Set the version directly here
    author="arcjetCV team",
    description="Package to process arcjet videos and segment the edge of the shock and of the sample",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/magnus-haw/arcjetCV",
    packages=find_packages(),
    include_package_data=True,  # Include package data based on the rules below
    package_data={
        "": ["*.txt", "*.md", "*.png", "*.gif"],  # Include these file types
        "arcjetCV": [
            "gui/logo/*.png",
            "gui/logo/*.ico",
            "gui/logo/*.icns",
        ],  # Include specific logo images
    },
    exclude_package_data={
        "arcjetCV": [
            "segmentation/contour/Unet-xception_25_original.pt",  # Exclude .pt files
            "segmentation/contour/Unet-xception-last-checkpoint.pt",
            "segmentation/contour/Unet-xception_25_weights_only.pt",
        ],
    },
    install_requires=[
        "pyside6>=6.5.0",  # Ensure compatibility with PySide6 versions
        "opencv-python",
        "opencv-contrib-python",
        "numpy",
        "matplotlib",
        "pandas",
        "pyarrow",
        "scikit-learn",
        "segmentation-models-pytorch",
        "torch",
        "torchvision",
    ],
    entry_points={
        "console_scripts": [
            "arcjetCV=arcjetCV.gui.main:main",
            "arcjetcv=arcjetCV.gui.main:main",
        ],
    },
    project_urls={
        "Bug Tracker": "https://github.com/magnus-haw/arcjetCV/issues",
    },
    platforms=["Linux", "Mac", "Windows"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Physics",
    ],
)
